/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the apigateway-2015-07-09.normal.json service model.
 */

using System;
using System.Collections.Generic;
using System.Text;
using System.Collections;
using System.Threading;
using System.Threading.Tasks;
using Amazon.Runtime;
 
namespace Amazon.APIGateway.Model
{
    /// <summary>
    /// Base class for GetDomainNames paginators.
    /// </summary>
    internal sealed partial class GetDomainNamesPaginator : IPaginator<GetDomainNamesResponse>, IGetDomainNamesPaginator
    {
        private readonly IAmazonAPIGateway _client;
        private readonly GetDomainNamesRequest _request;
        private int _isPaginatorInUse = 0;
        
        /// <summary>
        /// Enumerable containing all full responses for the operation
        /// </summary>
        public IPaginatedEnumerable<GetDomainNamesResponse> Responses => new PaginatedResponse<GetDomainNamesResponse>(this);

        /// <summary>
        /// Enumerable containing all of the Items
        /// </summary>
        public IPaginatedEnumerable<DomainName> Items => 
            new PaginatedResultKeyResponse<GetDomainNamesResponse, DomainName>(this, (i) => i.Items);

        internal GetDomainNamesPaginator(IAmazonAPIGateway client, GetDomainNamesRequest request)
        {
            this._client = client;
            this._request = request;
        }
#if BCL
        IEnumerable<GetDomainNamesResponse> IPaginator<GetDomainNamesResponse>.Paginate()
        {
            if (Interlocked.Exchange(ref _isPaginatorInUse, 1) != 0)
            {
                throw new System.InvalidOperationException("Paginator has already been consumed and cannot be reused. Please create a new instance.");
            }
            PaginatorUtils.SetUserAgentAdditionOnRequest(_request);
            var position = _request.Position;
            GetDomainNamesResponse response;
            do
            {
                _request.Position = position;
                response = _client.GetDomainNames(_request);
                position = response.Position;
                yield return response;
            }
            while (!string.IsNullOrEmpty(position));
        }
#endif
#if AWS_ASYNC_ENUMERABLES_API
        async IAsyncEnumerable<GetDomainNamesResponse> IPaginator<GetDomainNamesResponse>.PaginateAsync(CancellationToken cancellationToken = default)
        {
            if (Interlocked.Exchange(ref _isPaginatorInUse, 1) != 0)
            {
                throw new System.InvalidOperationException("Paginator has already been consumed and cannot be reused. Please create a new instance.");
            }
            PaginatorUtils.SetUserAgentAdditionOnRequest(_request);
            var position = _request.Position;
            GetDomainNamesResponse response;
            do
            {
                _request.Position = position;
                response = await _client.GetDomainNamesAsync(_request, cancellationToken).ConfigureAwait(false);
                position = response.Position;
                cancellationToken.ThrowIfCancellationRequested();
                yield return response;
            }
            while (!string.IsNullOrEmpty(position));
        }
#endif
    }
}