/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the accessanalyzer-2019-11-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.AccessAnalyzer.Model
{
    /// <summary>
    /// Container for the parameters to the StartPolicyGeneration operation.
    /// Starts the policy generation request.
    /// </summary>
    public partial class StartPolicyGenerationRequest : AmazonAccessAnalyzerRequest
    {
        private string _clientToken;
        private CloudTrailDetails _cloudTrailDetails;
        private PolicyGenerationDetails _policyGenerationDetails;

        /// <summary>
        /// Gets and sets the property ClientToken. 
        /// <para>
        /// A unique, case-sensitive identifier that you provide to ensure the idempotency of
        /// the request. Idempotency ensures that an API request completes only once. With an
        /// idempotent request, if the original request completes successfully, the subsequent
        /// retries with the same client token return the result from the original successful
        /// request and they have no additional effect.
        /// </para>
        ///  
        /// <para>
        /// If you do not specify a client token, one is automatically generated by the AWS SDK.
        /// </para>
        /// </summary>
        public string ClientToken
        {
            get { return this._clientToken; }
            set { this._clientToken = value; }
        }

        // Check to see if ClientToken property is set
        internal bool IsSetClientToken()
        {
            return this._clientToken != null;
        }

        /// <summary>
        /// Gets and sets the property CloudTrailDetails. 
        /// <para>
        /// A <code>CloudTrailDetails</code> object that contains details about a <code>Trail</code>
        /// that you want to analyze to generate policies.
        /// </para>
        /// </summary>
        public CloudTrailDetails CloudTrailDetails
        {
            get { return this._cloudTrailDetails; }
            set { this._cloudTrailDetails = value; }
        }

        // Check to see if CloudTrailDetails property is set
        internal bool IsSetCloudTrailDetails()
        {
            return this._cloudTrailDetails != null;
        }

        /// <summary>
        /// Gets and sets the property PolicyGenerationDetails. 
        /// <para>
        /// Contains the ARN of the IAM entity (user or role) for which you are generating a policy.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public PolicyGenerationDetails PolicyGenerationDetails
        {
            get { return this._policyGenerationDetails; }
            set { this._policyGenerationDetails = value; }
        }

        // Check to see if PolicyGenerationDetails property is set
        internal bool IsSetPolicyGenerationDetails()
        {
            return this._policyGenerationDetails != null;
        }

    }
}