/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the appsync-2017-07-25.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.AppSync.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.AppSync.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// AdditionalAuthenticationProvider Marshaller
    /// </summary>       
    public class AdditionalAuthenticationProviderMarshaller : IRequestMarshaller<AdditionalAuthenticationProvider, JsonMarshallerContext> 
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="requestObject"></param>
        /// <param name="context"></param>
        /// <returns></returns>
        public void Marshall(AdditionalAuthenticationProvider requestObject, JsonMarshallerContext context)
        {
            if(requestObject.IsSetAuthenticationType())
            {
                context.Writer.WritePropertyName("authenticationType");
                context.Writer.Write(requestObject.AuthenticationType);
            }

            if(requestObject.IsSetLambdaAuthorizerConfig())
            {
                context.Writer.WritePropertyName("lambdaAuthorizerConfig");
                context.Writer.WriteObjectStart();

                var marshaller = LambdaAuthorizerConfigMarshaller.Instance;
                marshaller.Marshall(requestObject.LambdaAuthorizerConfig, context);

                context.Writer.WriteObjectEnd();
            }

            if(requestObject.IsSetOpenIDConnectConfig())
            {
                context.Writer.WritePropertyName("openIDConnectConfig");
                context.Writer.WriteObjectStart();

                var marshaller = OpenIDConnectConfigMarshaller.Instance;
                marshaller.Marshall(requestObject.OpenIDConnectConfig, context);

                context.Writer.WriteObjectEnd();
            }

            if(requestObject.IsSetUserPoolConfig())
            {
                context.Writer.WritePropertyName("userPoolConfig");
                context.Writer.WriteObjectStart();

                var marshaller = CognitoUserPoolConfigMarshaller.Instance;
                marshaller.Marshall(requestObject.UserPoolConfig, context);

                context.Writer.WriteObjectEnd();
            }

        }

        /// <summary>
        /// Singleton Marshaller.
        /// </summary>  
        public readonly static AdditionalAuthenticationProviderMarshaller Instance = new AdditionalAuthenticationProviderMarshaller();

    }
}