/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the appsync-2017-07-25.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Net;
using System.Text;
using System.Xml.Serialization;

using Amazon.AppSync.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.AppSync.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// Response Unmarshaller for Resolver Object
    /// </summary>  
    public class ResolverUnmarshaller : IUnmarshaller<Resolver, XmlUnmarshallerContext>, IUnmarshaller<Resolver, JsonUnmarshallerContext>
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        Resolver IUnmarshaller<Resolver, XmlUnmarshallerContext>.Unmarshall(XmlUnmarshallerContext context)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        public Resolver Unmarshall(JsonUnmarshallerContext context)
        {
            context.Read();
            if (context.CurrentTokenType == JsonToken.Null) 
                return null;

            Resolver unmarshalledObject = new Resolver();
        
            int targetDepth = context.CurrentDepth;
            while (context.ReadAtDepth(targetDepth))
            {
                if (context.TestExpression("cachingConfig", targetDepth))
                {
                    var unmarshaller = CachingConfigUnmarshaller.Instance;
                    unmarshalledObject.CachingConfig = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("dataSourceName", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.DataSourceName = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("fieldName", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.FieldName = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("kind", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.Kind = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("pipelineConfig", targetDepth))
                {
                    var unmarshaller = PipelineConfigUnmarshaller.Instance;
                    unmarshalledObject.PipelineConfig = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("requestMappingTemplate", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.RequestMappingTemplate = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("resolverArn", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.ResolverArn = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("responseMappingTemplate", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.ResponseMappingTemplate = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("syncConfig", targetDepth))
                {
                    var unmarshaller = SyncConfigUnmarshaller.Instance;
                    unmarshalledObject.SyncConfig = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("typeName", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.TypeName = unmarshaller.Unmarshall(context);
                    continue;
                }
            }
          
            return unmarshalledObject;
        }


        private static ResolverUnmarshaller _instance = new ResolverUnmarshaller();        

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static ResolverUnmarshaller Instance
        {
            get
            {
                return _instance;
            }
        }
    }
}