/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the cloudformation-2010-05-15.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Net;
using System.Text;
using System.Xml.Serialization;

using Amazon.CloudFormation.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
namespace Amazon.CloudFormation.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// Response Unmarshaller for StackSetOperation Object
    /// </summary>  
    public class StackSetOperationUnmarshaller : IUnmarshaller<StackSetOperation, XmlUnmarshallerContext>, IUnmarshaller<StackSetOperation, JsonUnmarshallerContext>
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        public StackSetOperation Unmarshall(XmlUnmarshallerContext context)
        {
            StackSetOperation unmarshalledObject = new StackSetOperation();
            int originalDepth = context.CurrentDepth;
            int targetDepth = originalDepth + 1;
            
            if (context.IsStartOfDocument) 
               targetDepth += 2;
            
            while (context.ReadAtDepth(originalDepth))
            {
                if (context.IsStartElement || context.IsAttribute)
                {
                    if (context.TestExpression("Action", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.Action = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("AdministrationRoleARN", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.AdministrationRoleARN = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("CreationTimestamp", targetDepth))
                    {
                        var unmarshaller = DateTimeUnmarshaller.Instance;
                        unmarshalledObject.CreationTimestamp = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("DeploymentTargets", targetDepth))
                    {
                        var unmarshaller = DeploymentTargetsUnmarshaller.Instance;
                        unmarshalledObject.DeploymentTargets = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("EndTimestamp", targetDepth))
                    {
                        var unmarshaller = DateTimeUnmarshaller.Instance;
                        unmarshalledObject.EndTimestamp = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("ExecutionRoleName", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.ExecutionRoleName = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("OperationId", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.OperationId = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("OperationPreferences", targetDepth))
                    {
                        var unmarshaller = StackSetOperationPreferencesUnmarshaller.Instance;
                        unmarshalledObject.OperationPreferences = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("RetainStacks", targetDepth))
                    {
                        var unmarshaller = BoolUnmarshaller.Instance;
                        unmarshalledObject.RetainStacks = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("StackSetDriftDetectionDetails", targetDepth))
                    {
                        var unmarshaller = StackSetDriftDetectionDetailsUnmarshaller.Instance;
                        unmarshalledObject.StackSetDriftDetectionDetails = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("StackSetId", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.StackSetId = unmarshaller.Unmarshall(context);
                        continue;
                    }
                    if (context.TestExpression("Status", targetDepth))
                    {
                        var unmarshaller = StringUnmarshaller.Instance;
                        unmarshalledObject.Status = unmarshaller.Unmarshall(context);
                        continue;
                    }
                }
                else if (context.IsEndElement && context.CurrentDepth < originalDepth)
                {
                    return unmarshalledObject;
                }
            }

            return unmarshalledObject;
        }

        /// <summary>
        /// Unmarshaller error response to exception.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        public StackSetOperation Unmarshall(JsonUnmarshallerContext context)
        {
            return null;
        }


        private static StackSetOperationUnmarshaller _instance = new StackSetOperationUnmarshaller();        

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static StackSetOperationUnmarshaller Instance
        {
            get
            {
                return _instance;
            }
        }
    }
}