/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the codebuild-2016-10-06.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Net;
using System.Text;
using System.Xml.Serialization;

using Amazon.CodeBuild.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.CodeBuild.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// Response Unmarshaller for ProjectSource Object
    /// </summary>  
    public class ProjectSourceUnmarshaller : IUnmarshaller<ProjectSource, XmlUnmarshallerContext>, IUnmarshaller<ProjectSource, JsonUnmarshallerContext>
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        ProjectSource IUnmarshaller<ProjectSource, XmlUnmarshallerContext>.Unmarshall(XmlUnmarshallerContext context)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="context"></param>
        /// <returns></returns>
        public ProjectSource Unmarshall(JsonUnmarshallerContext context)
        {
            context.Read();
            if (context.CurrentTokenType == JsonToken.Null) 
                return null;

            ProjectSource unmarshalledObject = new ProjectSource();
        
            int targetDepth = context.CurrentDepth;
            while (context.ReadAtDepth(targetDepth))
            {
                if (context.TestExpression("auth", targetDepth))
                {
                    var unmarshaller = SourceAuthUnmarshaller.Instance;
                    unmarshalledObject.Auth = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("buildspec", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.Buildspec = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("buildStatusConfig", targetDepth))
                {
                    var unmarshaller = BuildStatusConfigUnmarshaller.Instance;
                    unmarshalledObject.BuildStatusConfig = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("gitCloneDepth", targetDepth))
                {
                    var unmarshaller = IntUnmarshaller.Instance;
                    unmarshalledObject.GitCloneDepth = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("gitSubmodulesConfig", targetDepth))
                {
                    var unmarshaller = GitSubmodulesConfigUnmarshaller.Instance;
                    unmarshalledObject.GitSubmodulesConfig = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("insecureSsl", targetDepth))
                {
                    var unmarshaller = BoolUnmarshaller.Instance;
                    unmarshalledObject.InsecureSsl = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("location", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.Location = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("reportBuildStatus", targetDepth))
                {
                    var unmarshaller = BoolUnmarshaller.Instance;
                    unmarshalledObject.ReportBuildStatus = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("sourceIdentifier", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.SourceIdentifier = unmarshaller.Unmarshall(context);
                    continue;
                }
                if (context.TestExpression("type", targetDepth))
                {
                    var unmarshaller = StringUnmarshaller.Instance;
                    unmarshalledObject.Type = unmarshaller.Unmarshall(context);
                    continue;
                }
            }
          
            return unmarshalledObject;
        }


        private static ProjectSourceUnmarshaller _instance = new ProjectSourceUnmarshaller();        

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static ProjectSourceUnmarshaller Instance
        {
            get
            {
                return _instance;
            }
        }
    }
}