/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the codeguru-reviewer-2019-09-19.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.CodeGuruReviewer.Model
{
    /// <summary>
    /// Information about recommendations.
    /// </summary>
    public partial class RecommendationSummary
    {
        private string _description;
        private int? _endLine;
        private string _filePath;
        private RecommendationCategory _recommendationCategory;
        private string _recommendationId;
        private int? _startLine;

        /// <summary>
        /// Gets and sets the property Description. 
        /// <para>
        ///  A description of the recommendation generated by CodeGuru Reviewer for the lines
        /// of code between the start line and the end line. 
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=2048)]
        public string Description
        {
            get { return this._description; }
            set { this._description = value; }
        }

        // Check to see if Description property is set
        internal bool IsSetDescription()
        {
            return this._description != null;
        }

        /// <summary>
        /// Gets and sets the property EndLine. 
        /// <para>
        ///  Last line where the recommendation is applicable in the source commit or source branch.
        /// For a single line comment the start line and end line values are the same. 
        /// </para>
        /// </summary>
        public int EndLine
        {
            get { return this._endLine.GetValueOrDefault(); }
            set { this._endLine = value; }
        }

        // Check to see if EndLine property is set
        internal bool IsSetEndLine()
        {
            return this._endLine.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property FilePath. 
        /// <para>
        /// Name of the file on which a recommendation is provided.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=1024)]
        public string FilePath
        {
            get { return this._filePath; }
            set { this._filePath = value; }
        }

        // Check to see if FilePath property is set
        internal bool IsSetFilePath()
        {
            return this._filePath != null;
        }

        /// <summary>
        /// Gets and sets the property RecommendationCategory. 
        /// <para>
        /// The type of a recommendation.
        /// </para>
        /// </summary>
        public RecommendationCategory RecommendationCategory
        {
            get { return this._recommendationCategory; }
            set { this._recommendationCategory = value; }
        }

        // Check to see if RecommendationCategory property is set
        internal bool IsSetRecommendationCategory()
        {
            return this._recommendationCategory != null;
        }

        /// <summary>
        /// Gets and sets the property RecommendationId. 
        /// <para>
        ///  The recommendation ID that can be used to track the provided recommendations. Later
        /// on it can be used to collect the feedback. 
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=64)]
        public string RecommendationId
        {
            get { return this._recommendationId; }
            set { this._recommendationId = value; }
        }

        // Check to see if RecommendationId property is set
        internal bool IsSetRecommendationId()
        {
            return this._recommendationId != null;
        }

        /// <summary>
        /// Gets and sets the property StartLine. 
        /// <para>
        ///  Start line from where the recommendation is applicable in the source commit or source
        /// branch. 
        /// </para>
        /// </summary>
        public int StartLine
        {
            get { return this._startLine.GetValueOrDefault(); }
            set { this._startLine = value; }
        }

        // Check to see if StartLine property is set
        internal bool IsSetStartLine()
        {
            return this._startLine.HasValue; 
        }

    }
}