/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the codepipeline-2015-07-09.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.CodePipeline.Model
{
    /// <summary>
    /// Input information used for an action execution.
    /// </summary>
    public partial class ActionExecutionInput
    {
        private ActionTypeId _actionTypeId;
        private Dictionary<string, string> _configuration = new Dictionary<string, string>();
        private List<ArtifactDetail> _inputArtifacts = new List<ArtifactDetail>();
        private string _awsNamespace;
        private string _region;
        private Dictionary<string, string> _resolvedConfiguration = new Dictionary<string, string>();
        private string _roleArn;

        /// <summary>
        /// Gets and sets the property ActionTypeId.
        /// </summary>
        public ActionTypeId ActionTypeId
        {
            get { return this._actionTypeId; }
            set { this._actionTypeId = value; }
        }

        // Check to see if ActionTypeId property is set
        internal bool IsSetActionTypeId()
        {
            return this._actionTypeId != null;
        }

        /// <summary>
        /// Gets and sets the property Configuration. 
        /// <para>
        /// Configuration data for an action execution.
        /// </para>
        /// </summary>
        public Dictionary<string, string> Configuration
        {
            get { return this._configuration; }
            set { this._configuration = value; }
        }

        // Check to see if Configuration property is set
        internal bool IsSetConfiguration()
        {
            return this._configuration != null && this._configuration.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property InputArtifacts. 
        /// <para>
        /// Details of input artifacts of the action that correspond to the action execution.
        /// </para>
        /// </summary>
        public List<ArtifactDetail> InputArtifacts
        {
            get { return this._inputArtifacts; }
            set { this._inputArtifacts = value; }
        }

        // Check to see if InputArtifacts property is set
        internal bool IsSetInputArtifacts()
        {
            return this._inputArtifacts != null && this._inputArtifacts.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Namespace. 
        /// <para>
        /// The variable namespace associated with the action. All variables produced as output
        /// by this action fall under this namespace.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=100)]
        public string Namespace
        {
            get { return this._awsNamespace; }
            set { this._awsNamespace = value; }
        }

        // Check to see if Namespace property is set
        internal bool IsSetNamespace()
        {
            return this._awsNamespace != null;
        }

        /// <summary>
        /// Gets and sets the property Region. 
        /// <para>
        /// The AWS Region for the action, such as us-east-1.
        /// </para>
        /// </summary>
        [AWSProperty(Min=4, Max=30)]
        public string Region
        {
            get { return this._region; }
            set { this._region = value; }
        }

        // Check to see if Region property is set
        internal bool IsSetRegion()
        {
            return this._region != null;
        }

        /// <summary>
        /// Gets and sets the property ResolvedConfiguration. 
        /// <para>
        /// Configuration data for an action execution with all variable references replaced with
        /// their real values for the execution.
        /// </para>
        /// </summary>
        public Dictionary<string, string> ResolvedConfiguration
        {
            get { return this._resolvedConfiguration; }
            set { this._resolvedConfiguration = value; }
        }

        // Check to see if ResolvedConfiguration property is set
        internal bool IsSetResolvedConfiguration()
        {
            return this._resolvedConfiguration != null && this._resolvedConfiguration.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property RoleArn. 
        /// <para>
        /// The ARN of the IAM service role that performs the declared action. This is assumed
        /// through the roleArn for the pipeline. 
        /// </para>
        /// </summary>
        [AWSProperty(Max=1024)]
        public string RoleArn
        {
            get { return this._roleArn; }
            set { this._roleArn = value; }
        }

        // Check to see if RoleArn property is set
        internal bool IsSetRoleArn()
        {
            return this._roleArn != null;
        }

    }
}