/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the codepipeline-2015-07-09.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.CodePipeline.Model
{
    /// <summary>
    /// Container for the parameters to the PutJobSuccessResult operation.
    /// Represents the success of a job as returned to the pipeline by a job worker. Used
    /// for custom actions only.
    /// </summary>
    public partial class PutJobSuccessResultRequest : AmazonCodePipelineRequest
    {
        private string _continuationToken;
        private CurrentRevision _currentRevision;
        private ExecutionDetails _executionDetails;
        private string _jobId;
        private Dictionary<string, string> _outputVariables = new Dictionary<string, string>();

        /// <summary>
        /// Gets and sets the property ContinuationToken. 
        /// <para>
        /// A token generated by a job worker, such as an AWS CodeDeploy deployment ID, that a
        /// successful job provides to identify a custom action in progress. Future jobs use this
        /// token to identify the running instance of the action. It can be reused to return more
        /// information about the progress of the custom action. When the action is complete,
        /// no continuation token should be supplied.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=2048)]
        public string ContinuationToken
        {
            get { return this._continuationToken; }
            set { this._continuationToken = value; }
        }

        // Check to see if ContinuationToken property is set
        internal bool IsSetContinuationToken()
        {
            return this._continuationToken != null;
        }

        /// <summary>
        /// Gets and sets the property CurrentRevision. 
        /// <para>
        /// The ID of the current revision of the artifact successfully worked on by the job.
        /// </para>
        /// </summary>
        public CurrentRevision CurrentRevision
        {
            get { return this._currentRevision; }
            set { this._currentRevision = value; }
        }

        // Check to see if CurrentRevision property is set
        internal bool IsSetCurrentRevision()
        {
            return this._currentRevision != null;
        }

        /// <summary>
        /// Gets and sets the property ExecutionDetails. 
        /// <para>
        /// The execution details of the successful job, such as the actions taken by the job
        /// worker.
        /// </para>
        /// </summary>
        public ExecutionDetails ExecutionDetails
        {
            get { return this._executionDetails; }
            set { this._executionDetails = value; }
        }

        // Check to see if ExecutionDetails property is set
        internal bool IsSetExecutionDetails()
        {
            return this._executionDetails != null;
        }

        /// <summary>
        /// Gets and sets the property JobId. 
        /// <para>
        /// The unique system-generated ID of the job that succeeded. This is the same ID returned
        /// from <code>PollForJobs</code>.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string JobId
        {
            get { return this._jobId; }
            set { this._jobId = value; }
        }

        // Check to see if JobId property is set
        internal bool IsSetJobId()
        {
            return this._jobId != null;
        }

        /// <summary>
        /// Gets and sets the property OutputVariables. 
        /// <para>
        /// Key-value pairs produced as output by a job worker that can be made available to a
        /// downstream action configuration. <code>outputVariables</code> can be included only
        /// when there is no continuation token on the request.
        /// </para>
        /// </summary>
        public Dictionary<string, string> OutputVariables
        {
            get { return this._outputVariables; }
            set { this._outputVariables = value; }
        }

        // Check to see if OutputVariables property is set
        internal bool IsSetOutputVariables()
        {
            return this._outputVariables != null && this._outputVariables.Count > 0; 
        }

    }
}