/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the devicefarm-2015-06-23.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.DeviceFarm.Model
{
    /// <summary>
    /// A JSON object that specifies the paths where the artifacts generated by the customer's
    /// tests, on the device or in the test environment, are pulled from.
    /// 
    ///  
    /// <para>
    /// Specify <code>deviceHostPaths</code> and optionally specify either <code>iosPaths</code>
    /// or <code>androidPaths</code>.
    /// </para>
    ///  
    /// <para>
    /// For web app tests, you can specify both <code>iosPaths</code> and <code>androidPaths</code>.
    /// </para>
    /// </summary>
    public partial class CustomerArtifactPaths
    {
        private List<string> _androidPaths = new List<string>();
        private List<string> _deviceHostPaths = new List<string>();
        private List<string> _iosPaths = new List<string>();

        /// <summary>
        /// Gets and sets the property AndroidPaths. 
        /// <para>
        /// Comma-separated list of paths on the Android device where the artifacts generated
        /// by the customer's tests are pulled from.
        /// </para>
        /// </summary>
        public List<string> AndroidPaths
        {
            get { return this._androidPaths; }
            set { this._androidPaths = value; }
        }

        // Check to see if AndroidPaths property is set
        internal bool IsSetAndroidPaths()
        {
            return this._androidPaths != null && this._androidPaths.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property DeviceHostPaths. 
        /// <para>
        /// Comma-separated list of paths in the test execution environment where the artifacts
        /// generated by the customer's tests are pulled from.
        /// </para>
        /// </summary>
        public List<string> DeviceHostPaths
        {
            get { return this._deviceHostPaths; }
            set { this._deviceHostPaths = value; }
        }

        // Check to see if DeviceHostPaths property is set
        internal bool IsSetDeviceHostPaths()
        {
            return this._deviceHostPaths != null && this._deviceHostPaths.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property IosPaths. 
        /// <para>
        /// Comma-separated list of paths on the iOS device where the artifacts generated by the
        /// customer's tests are pulled from.
        /// </para>
        /// </summary>
        public List<string> IosPaths
        {
            get { return this._iosPaths; }
            set { this._iosPaths = value; }
        }

        // Check to see if IosPaths property is set
        internal bool IsSetIosPaths()
        {
            return this._iosPaths != null && this._iosPaths.Count > 0; 
        }

    }
}