/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ebs-2019-11-02.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.EBS.Model
{
    /// <summary>
    /// Container for the parameters to the StartSnapshot operation.
    /// Creates a new Amazon EBS snapshot. The new snapshot enters the <code>pending</code>
    /// state after the request completes. 
    /// 
    ///  
    /// <para>
    /// After creating the snapshot, use <a href="https://docs.aws.amazon.com/ebs/latest/APIReference/API_PutSnapshotBlock.html">
    /// PutSnapshotBlock</a> to write blocks of data to the snapshot.
    /// </para>
    /// </summary>
    public partial class StartSnapshotRequest : AmazonEBSRequest
    {
        private string _clientToken;
        private string _description;
        private bool? _encrypted;
        private string _kmsKeyArn;
        private string _parentSnapshotId;
        private List<Tag> _tags = new List<Tag>();
        private int? _timeout;
        private long? _volumeSize;

        /// <summary>
        /// Gets and sets the property ClientToken. 
        /// <para>
        /// A unique, case-sensitive identifier that you provide to ensure the idempotency of
        /// the request. Idempotency ensures that an API request completes only once. With an
        /// idempotent request, if the original request completes successfully. The subsequent
        /// retries with the same client token return the result from the original successful
        /// request and they have no additional effect.
        /// </para>
        ///  
        /// <para>
        /// If you do not specify a client token, one is automatically generated by the Amazon
        /// Web Services SDK.
        /// </para>
        ///  
        /// <para>
        /// For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-direct-api-idempotency.html">
        /// Idempotency for StartSnapshot API</a> in the <i>Amazon Elastic Compute Cloud User
        /// Guide</i>.
        /// </para>
        /// </summary>
        [AWSProperty(Max=255)]
        public string ClientToken
        {
            get { return this._clientToken; }
            set { this._clientToken = value; }
        }

        // Check to see if ClientToken property is set
        internal bool IsSetClientToken()
        {
            return this._clientToken != null;
        }

        /// <summary>
        /// Gets and sets the property Description. 
        /// <para>
        /// A description for the snapshot.
        /// </para>
        /// </summary>
        [AWSProperty(Max=255)]
        public string Description
        {
            get { return this._description; }
            set { this._description = value; }
        }

        // Check to see if Description property is set
        internal bool IsSetDescription()
        {
            return this._description != null;
        }

        /// <summary>
        /// Gets and sets the property Encrypted. 
        /// <para>
        /// Indicates whether to encrypt the snapshot. To create an encrypted snapshot, specify
        /// <code>true</code>. To create an unencrypted snapshot, omit this parameter.
        /// </para>
        ///  
        /// <para>
        /// If you specify a value for <b>ParentSnapshotId</b>, omit this parameter.
        /// </para>
        ///  
        /// <para>
        /// If you specify <code>true</code>, the snapshot is encrypted using the KMS key specified
        /// using the <b>KmsKeyArn</b> parameter. If no value is specified for <b>KmsKeyArn</b>,
        /// the default KMS key for your account is used. If no default KMS key has been specified
        /// for your account, the Amazon Web Services managed KMS key is used. To set a default
        /// KMS key for your account, use <a href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyEbsDefaultKmsKeyId.html">
        /// ModifyEbsDefaultKmsKeyId</a>.
        /// </para>
        ///  
        /// <para>
        /// If your account is enabled for encryption by default, you cannot set this parameter
        /// to <code>false</code>. In this case, you can omit this parameter.
        /// </para>
        ///  
        /// <para>
        /// For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-accessing-snapshot.html#ebsapis-using-encryption">
        /// Using encryption</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.
        /// </para>
        /// </summary>
        public bool Encrypted
        {
            get { return this._encrypted.GetValueOrDefault(); }
            set { this._encrypted = value; }
        }

        // Check to see if Encrypted property is set
        internal bool IsSetEncrypted()
        {
            return this._encrypted.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property KmsKeyArn. 
        /// <para>
        /// The Amazon Resource Name (ARN) of the Key Management Service (KMS) key to be used
        /// to encrypt the snapshot. If you do not specify a KMS key, the default Amazon Web Services
        /// managed KMS key is used.
        /// </para>
        ///  
        /// <para>
        /// If you specify a <b>ParentSnapshotId</b>, omit this parameter; the snapshot will be
        /// encrypted using the same KMS key that was used to encrypt the parent snapshot.
        /// </para>
        ///  
        /// <para>
        /// If <b>Encrypted</b> is set to <code>true</code>, you must specify a KMS key ARN. 
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=2048)]
        public string KmsKeyArn
        {
            get { return this._kmsKeyArn; }
            set { this._kmsKeyArn = value; }
        }

        // Check to see if KmsKeyArn property is set
        internal bool IsSetKmsKeyArn()
        {
            return this._kmsKeyArn != null;
        }

        /// <summary>
        /// Gets and sets the property ParentSnapshotId. 
        /// <para>
        /// The ID of the parent snapshot. If there is no parent snapshot, or if you are creating
        /// the first snapshot for an on-premises volume, omit this parameter.
        /// </para>
        ///  
        /// <para>
        /// If your account is enabled for encryption by default, you cannot use an unencrypted
        /// snapshot as a parent snapshot. You must first create an encrypted copy of the parent
        /// snapshot using <a href="https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopySnapshot.html">CopySnapshot</a>.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=64)]
        public string ParentSnapshotId
        {
            get { return this._parentSnapshotId; }
            set { this._parentSnapshotId = value; }
        }

        // Check to see if ParentSnapshotId property is set
        internal bool IsSetParentSnapshotId()
        {
            return this._parentSnapshotId != null;
        }

        /// <summary>
        /// Gets and sets the property Tags. 
        /// <para>
        /// The tags to apply to the snapshot.
        /// </para>
        /// </summary>
        public List<Tag> Tags
        {
            get { return this._tags; }
            set { this._tags = value; }
        }

        // Check to see if Tags property is set
        internal bool IsSetTags()
        {
            return this._tags != null && this._tags.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Timeout. 
        /// <para>
        /// The amount of time (in minutes) after which the snapshot is automatically cancelled
        /// if:
        /// </para>
        ///  <ul> <li> 
        /// <para>
        /// No blocks are written to the snapshot.
        /// </para>
        ///  </li> <li> 
        /// <para>
        /// The snapshot is not completed after writing the last block of data.
        /// </para>
        ///  </li> </ul> 
        /// <para>
        /// If no value is specified, the timeout defaults to <code>60</code> minutes.
        /// </para>
        /// </summary>
        [AWSProperty(Min=10, Max=60)]
        public int Timeout
        {
            get { return this._timeout.GetValueOrDefault(); }
            set { this._timeout = value; }
        }

        // Check to see if Timeout property is set
        internal bool IsSetTimeout()
        {
            return this._timeout.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property VolumeSize. 
        /// <para>
        /// The size of the volume, in GiB. The maximum size is <code>16384</code> GiB (16 TiB).
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1)]
        public long VolumeSize
        {
            get { return this._volumeSize.GetValueOrDefault(); }
            set { this._volumeSize = value; }
        }

        // Check to see if VolumeSize property is set
        internal bool IsSetVolumeSize()
        {
            return this._volumeSize.HasValue; 
        }

    }
}