/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ec2-2016-11-15.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.EC2.Model
{
    /// <summary>
    /// Container for the parameters to the DetachNetworkInterface operation.
    /// Detaches a network interface from an instance.
    /// </summary>
    public partial class DetachNetworkInterfaceRequest : AmazonEC2Request
    {
        private string _attachmentId;
        private bool? _force;

        /// <summary>
        /// Gets and sets the property AttachmentId. 
        /// <para>
        /// The ID of the attachment.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string AttachmentId
        {
            get { return this._attachmentId; }
            set { this._attachmentId = value; }
        }

        // Check to see if AttachmentId property is set
        internal bool IsSetAttachmentId()
        {
            return this._attachmentId != null;
        }

        /// <summary>
        /// Gets and sets the property Force. 
        /// <para>
        /// Specifies whether to force a detachment.
        /// </para>
        ///  <note> <ul> <li> 
        /// <para>
        /// Use the <code>Force</code> parameter only as a last resort to detach a network interface
        /// from a failed instance. 
        /// </para>
        ///  </li> <li> 
        /// <para>
        /// If you use the <code>Force</code> parameter to detach a network interface, you might
        /// not be able to attach a different network interface to the same index on the instance
        /// without first stopping and starting the instance.
        /// </para>
        ///  </li> <li> 
        /// <para>
        /// If you force the detachment of a network interface, the <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-metadata.html">instance
        /// metadata</a> might not get updated. This means that the attributes associated with
        /// the detached network interface might still be visible. The instance metadata will
        /// get updated when you stop and start the instance.
        /// </para>
        ///  </li> </ul> </note>
        /// </summary>
        public bool Force
        {
            get { return this._force.GetValueOrDefault(); }
            set { this._force = value; }
        }

        // Check to see if Force property is set
        internal bool IsSetForce()
        {
            return this._force.HasValue; 
        }

    }
}