/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ec2-2016-11-15.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.EC2.Model
{
    /// <summary>
    /// Container for the parameters to the DisassociateEnclaveCertificateIamRole operation.
    /// Disassociates an IAM role from an Certificate Manager (ACM) certificate. Disassociating
    /// an IAM role from an ACM certificate removes the Amazon S3 object that contains the
    /// certificate, certificate chain, and encrypted private key from the Amazon S3 bucket.
    /// It also revokes the IAM role's permission to use the KMS key used to encrypt the private
    /// key. This effectively revokes the role's permission to use the certificate.
    /// </summary>
    public partial class DisassociateEnclaveCertificateIamRoleRequest : AmazonEC2Request
    {
        private string _certificateArn;
        private string _roleArn;

        /// <summary>
        /// Gets and sets the property CertificateArn. 
        /// <para>
        /// The ARN of the ACM certificate from which to disassociate the IAM role.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=1283)]
        public string CertificateArn
        {
            get { return this._certificateArn; }
            set { this._certificateArn = value; }
        }

        // Check to see if CertificateArn property is set
        internal bool IsSetCertificateArn()
        {
            return this._certificateArn != null;
        }

        /// <summary>
        /// Gets and sets the property RoleArn. 
        /// <para>
        /// The ARN of the IAM role to disassociate.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=1283)]
        public string RoleArn
        {
            get { return this._roleArn; }
            set { this._roleArn = value; }
        }

        // Check to see if RoleArn property is set
        internal bool IsSetRoleArn()
        {
            return this._roleArn != null;
        }

    }
}