/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the elasticfilesystem-2015-02-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.ElasticFileSystem.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.ElasticFileSystem.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// CreateFileSystem Request Marshaller
    /// </summary>       
    public class CreateFileSystemRequestMarshaller : IMarshaller<IRequest, CreateFileSystemRequest> , IMarshaller<IRequest,AmazonWebServiceRequest>
    {
        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="input"></param>
        /// <returns></returns>
        public IRequest Marshall(AmazonWebServiceRequest input)
        {
            return this.Marshall((CreateFileSystemRequest)input);
        }

        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="publicRequest"></param>
        /// <returns></returns>
        public IRequest Marshall(CreateFileSystemRequest publicRequest)
        {
            IRequest request = new DefaultRequest(publicRequest, "Amazon.ElasticFileSystem");
            request.Headers["Content-Type"] = "application/json";
            request.Headers[Amazon.Util.HeaderKeys.XAmzApiVersion] = "2015-02-01";            
            request.HttpMethod = "POST";

            request.ResourcePath = "/2015-02-01/file-systems";
            using (StringWriter stringWriter = new StringWriter(CultureInfo.InvariantCulture))
            {
                JsonWriter writer = new JsonWriter(stringWriter);
                writer.WriteObjectStart();
                var context = new JsonMarshallerContext(request, writer);
                if(publicRequest.IsSetAvailabilityZoneName())
                {
                    context.Writer.WritePropertyName("AvailabilityZoneName");
                    context.Writer.Write(publicRequest.AvailabilityZoneName);
                }

                if(publicRequest.IsSetBackup())
                {
                    context.Writer.WritePropertyName("Backup");
                    context.Writer.Write(publicRequest.Backup);
                }

                if(publicRequest.IsSetCreationToken())
                {
                    context.Writer.WritePropertyName("CreationToken");
                    context.Writer.Write(publicRequest.CreationToken);
                }

                else if(!(publicRequest.IsSetCreationToken()))
                {
                    context.Writer.WritePropertyName("CreationToken");
                    context.Writer.Write(Guid.NewGuid().ToString());                                                
                }
                if(publicRequest.IsSetEncrypted())
                {
                    context.Writer.WritePropertyName("Encrypted");
                    context.Writer.Write(publicRequest.Encrypted);
                }

                if(publicRequest.IsSetKmsKeyId())
                {
                    context.Writer.WritePropertyName("KmsKeyId");
                    context.Writer.Write(publicRequest.KmsKeyId);
                }

                if(publicRequest.IsSetPerformanceMode())
                {
                    context.Writer.WritePropertyName("PerformanceMode");
                    context.Writer.Write(publicRequest.PerformanceMode);
                }

                if(publicRequest.IsSetProvisionedThroughputInMibps())
                {
                    context.Writer.WritePropertyName("ProvisionedThroughputInMibps");
                    context.Writer.Write(publicRequest.ProvisionedThroughputInMibps);
                }

                if(publicRequest.IsSetTags())
                {
                    context.Writer.WritePropertyName("Tags");
                    context.Writer.WriteArrayStart();
                    foreach(var publicRequestTagsListValue in publicRequest.Tags)
                    {
                        context.Writer.WriteObjectStart();

                        var marshaller = TagMarshaller.Instance;
                        marshaller.Marshall(publicRequestTagsListValue, context);

                        context.Writer.WriteObjectEnd();
                    }
                    context.Writer.WriteArrayEnd();
                }

                if(publicRequest.IsSetThroughputMode())
                {
                    context.Writer.WritePropertyName("ThroughputMode");
                    context.Writer.Write(publicRequest.ThroughputMode);
                }

        
                writer.WriteObjectEnd();
                string snippet = stringWriter.ToString();
                request.Content = System.Text.Encoding.UTF8.GetBytes(snippet);
            }


            return request;
        }
        private static CreateFileSystemRequestMarshaller _instance = new CreateFileSystemRequestMarshaller();        

        internal static CreateFileSystemRequestMarshaller GetInstance()
        {
            return _instance;
        }

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static CreateFileSystemRequestMarshaller Instance
        {
            get
            {
                return _instance;
            }
        }

    }
}