/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the elasticloadbalancingv2-2015-12-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.ElasticLoadBalancingV2.Model
{
    /// <summary>
    /// Container for the parameters to the DescribeLoadBalancers operation.
    /// Describes the specified load balancers or all of your load balancers.
    /// </summary>
    public partial class DescribeLoadBalancersRequest : AmazonElasticLoadBalancingV2Request
    {
        private List<string> _loadBalancerArns = new List<string>();
        private string _marker;
        private List<string> _names = new List<string>();
        private int? _pageSize;

        /// <summary>
        /// Gets and sets the property LoadBalancerArns. 
        /// <para>
        /// The Amazon Resource Names (ARN) of the load balancers. You can specify up to 20 load
        /// balancers in a single call.
        /// </para>
        /// </summary>
        public List<string> LoadBalancerArns
        {
            get { return this._loadBalancerArns; }
            set { this._loadBalancerArns = value; }
        }

        // Check to see if LoadBalancerArns property is set
        internal bool IsSetLoadBalancerArns()
        {
            return this._loadBalancerArns != null && this._loadBalancerArns.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Marker. 
        /// <para>
        /// The marker for the next set of results. (You received this marker from a previous
        /// call.)
        /// </para>
        /// </summary>
        public string Marker
        {
            get { return this._marker; }
            set { this._marker = value; }
        }

        // Check to see if Marker property is set
        internal bool IsSetMarker()
        {
            return this._marker != null;
        }

        /// <summary>
        /// Gets and sets the property Names. 
        /// <para>
        /// The names of the load balancers.
        /// </para>
        /// </summary>
        public List<string> Names
        {
            get { return this._names; }
            set { this._names = value; }
        }

        // Check to see if Names property is set
        internal bool IsSetNames()
        {
            return this._names != null && this._names.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property PageSize. 
        /// <para>
        /// The maximum number of results to return with this call.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=400)]
        public int PageSize
        {
            get { return this._pageSize.GetValueOrDefault(); }
            set { this._pageSize = value; }
        }

        // Check to see if PageSize property is set
        internal bool IsSetPageSize()
        {
            return this._pageSize.HasValue; 
        }

    }
}