/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the fsx-2018-03-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.FSx.Model
{
    /// <summary>
    /// Container for the parameters to the DisassociateFileSystemAliases operation.
    /// Use this action to disassociate, or remove, one or more Domain Name Service (DNS)
    /// aliases from an Amazon FSx for Windows File Server file system. If you attempt to
    /// disassociate a DNS alias that is not associated with the file system, Amazon FSx responds
    /// with a 400 Bad Request. For more information, see <a href="https://docs.aws.amazon.com/fsx/latest/WindowsGuide/managing-dns-aliases.html">Working
    /// with DNS Aliases</a>.
    /// 
    ///  
    /// <para>
    /// The system generated response showing the DNS aliases that Amazon FSx is attempting
    /// to disassociate from the file system. Use the API operation to monitor the status
    /// of the aliases Amazon FSx is disassociating with the file system.
    /// </para>
    /// </summary>
    public partial class DisassociateFileSystemAliasesRequest : AmazonFSxRequest
    {
        private List<string> _aliases = new List<string>();
        private string _clientRequestToken;
        private string _fileSystemId;

        /// <summary>
        /// Gets and sets the property Aliases. 
        /// <para>
        /// An array of one or more DNS alias names to disassociate, or remove, from the file
        /// system.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Max=50)]
        public List<string> Aliases
        {
            get { return this._aliases; }
            set { this._aliases = value; }
        }

        // Check to see if Aliases property is set
        internal bool IsSetAliases()
        {
            return this._aliases != null && this._aliases.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property ClientRequestToken.
        /// </summary>
        [AWSProperty(Min=1, Max=63)]
        public string ClientRequestToken
        {
            get { return this._clientRequestToken; }
            set { this._clientRequestToken = value; }
        }

        // Check to see if ClientRequestToken property is set
        internal bool IsSetClientRequestToken()
        {
            return this._clientRequestToken != null;
        }

        /// <summary>
        /// Gets and sets the property FileSystemId. 
        /// <para>
        /// Specifies the file system from which to disassociate the DNS aliases.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=11, Max=21)]
        public string FileSystemId
        {
            get { return this._fileSystemId; }
            set { this._fileSystemId = value; }
        }

        // Check to see if FileSystemId property is set
        internal bool IsSetFileSystemId()
        {
            return this._fileSystemId != null;
        }

    }
}