/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the forecastquery-2018-06-26.normal.json service model.
 */


using System;
using System.Collections.Generic;

using Amazon.Runtime;
using Amazon.ForecastQueryService.Model;

namespace Amazon.ForecastQueryService
{
    /// <summary>
    /// Interface for accessing ForecastQueryService
    ///
    /// Provides APIs for creating and managing Amazon Forecast resources.
    /// </summary>
    public partial interface IAmazonForecastQueryService : IAmazonService, IDisposable
    {




        
        #region  QueryForecast


        /// <summary>
        /// Retrieves a forecast for a single item, filtered by the supplied criteria.
        /// 
        ///  
        /// <para>
        /// The criteria is a key-value pair. The key is either <code>item_id</code> (or the equivalent
        /// non-timestamp, non-target field) from the <code>TARGET_TIME_SERIES</code> dataset,
        /// or one of the forecast dimensions specified as part of the <code>FeaturizationConfig</code>
        /// object.
        /// </para>
        ///  
        /// <para>
        /// By default, <code>QueryForecast</code> returns the complete date range for the filtered
        /// forecast. You can request a specific date range.
        /// </para>
        ///  
        /// <para>
        /// To get the full forecast, use the <a href="https://docs.aws.amazon.com/en_us/forecast/latest/dg/API_CreateForecastExportJob.html">CreateForecastExportJob</a>
        /// operation.
        /// </para>
        ///  <note> 
        /// <para>
        /// The forecasts generated by Amazon Forecast are in the same timezone as the dataset
        /// that was used to create the predictor.
        /// </para>
        ///  </note>
        /// </summary>
        /// <param name="request">Container for the necessary parameters to execute the QueryForecast service method.</param>
        /// 
        /// <returns>The response from the QueryForecast service method, as returned by ForecastQueryService.</returns>
        /// <exception cref="Amazon.ForecastQueryService.Model.InvalidInputException">
        /// The value is invalid or is too long.
        /// </exception>
        /// <exception cref="Amazon.ForecastQueryService.Model.InvalidNextTokenException">
        /// The token is not valid. Tokens expire after 24 hours.
        /// </exception>
        /// <exception cref="Amazon.ForecastQueryService.Model.LimitExceededException">
        /// The limit on the number of requests per second has been exceeded.
        /// </exception>
        /// <exception cref="Amazon.ForecastQueryService.Model.ResourceInUseException">
        /// The specified resource is in use.
        /// </exception>
        /// <exception cref="Amazon.ForecastQueryService.Model.ResourceNotFoundException">
        /// We can't find that resource. Check the information that you've provided and try again.
        /// </exception>
        /// <seealso href="http://docs.aws.amazon.com/goto/WebAPI/forecastquery-2018-06-26/QueryForecast">REST API Reference for QueryForecast Operation</seealso>
        QueryForecastResponse QueryForecast(QueryForecastRequest request);

        /// <summary>
        /// Initiates the asynchronous execution of the QueryForecast operation.
        /// </summary>
        /// 
        /// <param name="request">Container for the necessary parameters to execute the QueryForecast operation on AmazonForecastQueryServiceClient.</param>
        /// <param name="callback">An AsyncCallback delegate that is invoked when the operation completes.</param>
        /// <param name="state">A user-defined state object that is passed to the callback procedure. Retrieve this object from within the callback
        ///          procedure using the AsyncState property.</param>
        /// 
        /// <returns>An IAsyncResult that can be used to poll or wait for results, or both; this value is also needed when invoking EndQueryForecast
        ///         operation.</returns>
        /// <seealso href="http://docs.aws.amazon.com/goto/WebAPI/forecastquery-2018-06-26/QueryForecast">REST API Reference for QueryForecast Operation</seealso>
        IAsyncResult BeginQueryForecast(QueryForecastRequest request, AsyncCallback callback, object state);



        /// <summary>
        /// Finishes the asynchronous execution of the  QueryForecast operation.
        /// </summary>
        /// 
        /// <param name="asyncResult">The IAsyncResult returned by the call to BeginQueryForecast.</param>
        /// 
        /// <returns>Returns a  QueryForecastResult from ForecastQueryService.</returns>
        /// <seealso href="http://docs.aws.amazon.com/goto/WebAPI/forecastquery-2018-06-26/QueryForecast">REST API Reference for QueryForecast Operation</seealso>
        QueryForecastResponse EndQueryForecast(IAsyncResult asyncResult);

        #endregion
        
    }
}