/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the glue-2017-03-31.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Glue.Model
{
    /// <summary>
    /// Container for the parameters to the GetPlan operation.
    /// Gets code to perform a specified mapping.
    /// </summary>
    public partial class GetPlanRequest : AmazonGlueRequest
    {
        private Dictionary<string, string> _additionalPlanOptionsMap = new Dictionary<string, string>();
        private Language _language;
        private Location _location;
        private List<MappingEntry> _mapping = new List<MappingEntry>();
        private List<CatalogEntry> _sinks = new List<CatalogEntry>();
        private CatalogEntry _source;

        /// <summary>
        /// Gets and sets the property AdditionalPlanOptionsMap. 
        /// <para>
        /// A map to hold additional optional key-value parameters.
        /// </para>
        ///  
        /// <para>
        /// Currently, these key-value pairs are supported:
        /// </para>
        ///  <ul> <li> 
        /// <para>
        ///  <code>inferSchema</code>  —  Specifies whether to set <code>inferSchema</code> to
        /// true or false for the default script generated by an Glue job. For example, to set
        /// <code>inferSchema</code> to true, pass the following key value pair:
        /// </para>
        ///  
        /// <para>
        ///  <code>--additional-plan-options-map '{"inferSchema":"true"}'</code> 
        /// </para>
        ///  </li> </ul>
        /// </summary>
        public Dictionary<string, string> AdditionalPlanOptionsMap
        {
            get { return this._additionalPlanOptionsMap; }
            set { this._additionalPlanOptionsMap = value; }
        }

        // Check to see if AdditionalPlanOptionsMap property is set
        internal bool IsSetAdditionalPlanOptionsMap()
        {
            return this._additionalPlanOptionsMap != null && this._additionalPlanOptionsMap.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Language. 
        /// <para>
        /// The programming language of the code to perform the mapping.
        /// </para>
        /// </summary>
        public Language Language
        {
            get { return this._language; }
            set { this._language = value; }
        }

        // Check to see if Language property is set
        internal bool IsSetLanguage()
        {
            return this._language != null;
        }

        /// <summary>
        /// Gets and sets the property Location. 
        /// <para>
        /// The parameters for the mapping.
        /// </para>
        /// </summary>
        public Location Location
        {
            get { return this._location; }
            set { this._location = value; }
        }

        // Check to see if Location property is set
        internal bool IsSetLocation()
        {
            return this._location != null;
        }

        /// <summary>
        /// Gets and sets the property Mapping. 
        /// <para>
        /// The list of mappings from a source table to target tables.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public List<MappingEntry> Mapping
        {
            get { return this._mapping; }
            set { this._mapping = value; }
        }

        // Check to see if Mapping property is set
        internal bool IsSetMapping()
        {
            return this._mapping != null && this._mapping.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Sinks. 
        /// <para>
        /// The target tables.
        /// </para>
        /// </summary>
        public List<CatalogEntry> Sinks
        {
            get { return this._sinks; }
            set { this._sinks = value; }
        }

        // Check to see if Sinks property is set
        internal bool IsSetSinks()
        {
            return this._sinks != null && this._sinks.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Source. 
        /// <para>
        /// The source table.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public CatalogEntry Source
        {
            get { return this._source; }
            set { this._source = value; }
        }

        // Check to see if Source property is set
        internal bool IsSetSource()
        {
            return this._source != null;
        }

    }
}