/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the databrew-2017-07-25.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.GlueDataBrew.Model
{
    /// <summary>
    /// Represents a JDBC database output object which defines the output destination for
    /// a DataBrew recipe job to write into.
    /// </summary>
    public partial class DatabaseOutput
    {
        private DatabaseTableOutputOptions _databaseOptions;
        private DatabaseOutputMode _databaseOutputMode;
        private string _glueConnectionName;

        /// <summary>
        /// Gets and sets the property DatabaseOptions. 
        /// <para>
        /// Represents options that specify how and where DataBrew writes the database output
        /// generated by recipe jobs.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public DatabaseTableOutputOptions DatabaseOptions
        {
            get { return this._databaseOptions; }
            set { this._databaseOptions = value; }
        }

        // Check to see if DatabaseOptions property is set
        internal bool IsSetDatabaseOptions()
        {
            return this._databaseOptions != null;
        }

        /// <summary>
        /// Gets and sets the property DatabaseOutputMode. 
        /// <para>
        /// The output mode to write into the database. Currently supported option: NEW_TABLE.
        /// </para>
        /// </summary>
        public DatabaseOutputMode DatabaseOutputMode
        {
            get { return this._databaseOutputMode; }
            set { this._databaseOutputMode = value; }
        }

        // Check to see if DatabaseOutputMode property is set
        internal bool IsSetDatabaseOutputMode()
        {
            return this._databaseOutputMode != null;
        }

        /// <summary>
        /// Gets and sets the property GlueConnectionName. 
        /// <para>
        /// The Glue connection that stores the connection information for the target database.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=255)]
        public string GlueConnectionName
        {
            get { return this._glueConnectionName; }
            set { this._glueConnectionName = value; }
        }

        // Check to see if GlueConnectionName property is set
        internal bool IsSetGlueConnectionName()
        {
            return this._glueConnectionName != null;
        }

    }
}