/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ivs-2020-07-14.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.IVS.Model
{
    /// <summary>
    /// Container for the parameters to the StopStream operation.
    /// Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction
    /// with <a>DeleteStreamKey</a> to prevent further streaming to a channel.
    /// 
    ///  <note> 
    /// <para>
    /// Many streaming client-software libraries automatically reconnect a dropped RTMPS session,
    /// so to stop the stream permanently, you may want to first revoke the <code>streamKey</code>
    /// attached to the channel.
    /// </para>
    ///  </note>
    /// </summary>
    public partial class StopStreamRequest : AmazonIVSRequest
    {
        private string _channelArn;

        /// <summary>
        /// Gets and sets the property ChannelArn. 
        /// <para>
        /// ARN of the channel for which the stream is to be stopped.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=128)]
        public string ChannelArn
        {
            get { return this._channelArn; }
            set { this._channelArn = value; }
        }

        // Check to see if ChannelArn property is set
        internal bool IsSetChannelArn()
        {
            return this._channelArn != null;
        }

    }
}