/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the iam-2010-05-08.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.IdentityManagement.Model
{
    /// <summary>
    /// Container for the parameters to the GetOrganizationsAccessReport operation.
    /// Retrieves the service last accessed data report for Organizations that was previously
    /// generated using the <code> <a>GenerateOrganizationsAccessReport</a> </code> operation.
    /// This operation retrieves the status of your report job and the report contents.
    /// 
    ///  
    /// <para>
    /// Depending on the parameters that you passed when you generated the report, the data
    /// returned could include different information. For details, see <a>GenerateOrganizationsAccessReport</a>.
    /// </para>
    ///  
    /// <para>
    /// To call this operation, you must be signed in to the management account in your organization.
    /// SCPs must be enabled for your organization root. You must have permissions to perform
    /// this operation. For more information, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html">Refining
    /// permissions using service last accessed data</a> in the <i>IAM User Guide</i>.
    /// </para>
    ///  
    /// <para>
    /// For each service that principals in an account (root users, IAM users, or IAM roles)
    /// could access using SCPs, the operation returns details about the most recent access
    /// attempt. If there was no attempt, the service is listed without details about the
    /// most recent attempt to access the service. If the operation fails, it returns the
    /// reason that it failed.
    /// </para>
    ///  
    /// <para>
    /// By default, the list is sorted by service namespace.
    /// </para>
    /// </summary>
    public partial class GetOrganizationsAccessReportRequest : AmazonIdentityManagementServiceRequest
    {
        private string _jobId;
        private string _marker;
        private int? _maxItems;
        private SortKeyType _sortKey;

        /// <summary>
        /// Gets and sets the property JobId. 
        /// <para>
        /// The identifier of the request generated by the <a>GenerateOrganizationsAccessReport</a>
        /// operation.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=36, Max=36)]
        public string JobId
        {
            get { return this._jobId; }
            set { this._jobId = value; }
        }

        // Check to see if JobId property is set
        internal bool IsSetJobId()
        {
            return this._jobId != null;
        }

        /// <summary>
        /// Gets and sets the property Marker. 
        /// <para>
        /// Use this parameter only when paginating results and only after you receive a response
        /// indicating that the results are truncated. Set it to the value of the <code>Marker</code>
        /// element in the response that you received to indicate where the next call should start.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=320)]
        public string Marker
        {
            get { return this._marker; }
            set { this._marker = value; }
        }

        // Check to see if Marker property is set
        internal bool IsSetMarker()
        {
            return this._marker != null;
        }

        /// <summary>
        /// Gets and sets the property MaxItems. 
        /// <para>
        /// Use this only when paginating results to indicate the maximum number of items you
        /// want in the response. If additional items exist beyond the maximum you specify, the
        /// <code>IsTruncated</code> response element is <code>true</code>.
        /// </para>
        ///  
        /// <para>
        /// If you do not include this parameter, the number of items defaults to 100. Note that
        /// IAM might return fewer results, even when there are more results available. In that
        /// case, the <code>IsTruncated</code> response element returns <code>true</code>, and
        /// <code>Marker</code> contains a value to include in the subsequent call that tells
        /// the service where to continue from.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=1000)]
        public int MaxItems
        {
            get { return this._maxItems.GetValueOrDefault(); }
            set { this._maxItems = value; }
        }

        // Check to see if MaxItems property is set
        internal bool IsSetMaxItems()
        {
            return this._maxItems.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property SortKey. 
        /// <para>
        /// The key that is used to sort the results. If you choose the namespace key, the results
        /// are returned in alphabetical order. If you choose the time key, the results are sorted
        /// numerically by the date and time.
        /// </para>
        /// </summary>
        public SortKeyType SortKey
        {
            get { return this._sortKey; }
            set { this._sortKey = value; }
        }

        // Check to see if SortKey property is set
        internal bool IsSetSortKey()
        {
            return this._sortKey != null;
        }

    }
}