/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the iot-2015-05-28.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.IoT.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.IoT.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// GetPercentiles Request Marshaller
    /// </summary>       
    public class GetPercentilesRequestMarshaller : IMarshaller<IRequest, GetPercentilesRequest> , IMarshaller<IRequest,AmazonWebServiceRequest>
    {
        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="input"></param>
        /// <returns></returns>
        public IRequest Marshall(AmazonWebServiceRequest input)
        {
            return this.Marshall((GetPercentilesRequest)input);
        }

        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="publicRequest"></param>
        /// <returns></returns>
        public IRequest Marshall(GetPercentilesRequest publicRequest)
        {
            IRequest request = new DefaultRequest(publicRequest, "Amazon.IoT");
            request.Headers["Content-Type"] = "application/json";
            request.Headers[Amazon.Util.HeaderKeys.XAmzApiVersion] = "2015-05-28";            
            request.HttpMethod = "POST";

            request.ResourcePath = "/indices/percentiles";
            using (StringWriter stringWriter = new StringWriter(CultureInfo.InvariantCulture))
            {
                JsonWriter writer = new JsonWriter(stringWriter);
                writer.WriteObjectStart();
                var context = new JsonMarshallerContext(request, writer);
                if(publicRequest.IsSetAggregationField())
                {
                    context.Writer.WritePropertyName("aggregationField");
                    context.Writer.Write(publicRequest.AggregationField);
                }

                if(publicRequest.IsSetIndexName())
                {
                    context.Writer.WritePropertyName("indexName");
                    context.Writer.Write(publicRequest.IndexName);
                }

                if(publicRequest.IsSetPercents())
                {
                    context.Writer.WritePropertyName("percents");
                    context.Writer.WriteArrayStart();
                    foreach(var publicRequestPercentsListValue in publicRequest.Percents)
                    {
                            context.Writer.Write(publicRequestPercentsListValue);
                    }
                    context.Writer.WriteArrayEnd();
                }

                if(publicRequest.IsSetQueryString())
                {
                    context.Writer.WritePropertyName("queryString");
                    context.Writer.Write(publicRequest.QueryString);
                }

                if(publicRequest.IsSetQueryVersion())
                {
                    context.Writer.WritePropertyName("queryVersion");
                    context.Writer.Write(publicRequest.QueryVersion);
                }

        
                writer.WriteObjectEnd();
                string snippet = stringWriter.ToString();
                request.Content = System.Text.Encoding.UTF8.GetBytes(snippet);
            }


            return request;
        }
        private static GetPercentilesRequestMarshaller _instance = new GetPercentilesRequestMarshaller();        

        internal static GetPercentilesRequestMarshaller GetInstance()
        {
            return _instance;
        }

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static GetPercentilesRequestMarshaller Instance
        {
            get
            {
                return _instance;
            }
        }

    }
}