/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the iotanalytics-2017-11-27.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.IoTAnalytics.Model
{
    /// <summary>
    /// Used to store data used by IoT SiteWise in an Amazon S3 bucket that you manage. You
    /// can't change the choice of Amazon S3 storage after your data store is created.
    /// </summary>
    public partial class IotSiteWiseCustomerManagedDatastoreS3Storage
    {
        private string _bucket;
        private string _keyPrefix;

        /// <summary>
        /// Gets and sets the property Bucket. 
        /// <para>
        ///  The name of the Amazon S3 bucket where your data is stored. 
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=3, Max=255)]
        public string Bucket
        {
            get { return this._bucket; }
            set { this._bucket = value; }
        }

        // Check to see if Bucket property is set
        internal bool IsSetBucket()
        {
            return this._bucket != null;
        }

        /// <summary>
        /// Gets and sets the property KeyPrefix. 
        /// <para>
        ///  (Optional) The prefix used to create the keys of the data store data objects. Each
        /// object in an Amazon S3 bucket has a key that is its unique identifier in the bucket.
        /// Each object in a bucket has exactly one key. The prefix must end with a forward slash
        /// (/). 
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=255)]
        public string KeyPrefix
        {
            get { return this._keyPrefix; }
            set { this._keyPrefix = value; }
        }

        // Check to see if KeyPrefix property is set
        internal bool IsSetKeyPrefix()
        {
            return this._keyPrefix != null;
        }

    }
}