/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the iotsitewise-2019-12-02.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.IoTSiteWise.Model
{
    /// <summary>
    /// Contains the (pre-calculated) aggregate values for an asset property.
    /// </summary>
    public partial class Aggregates
    {
        private double? _average;
        private double? _count;
        private double? _maximum;
        private double? _minimum;
        private double? _standardDeviation;
        private double? _sum;

        /// <summary>
        /// Gets and sets the property Average. 
        /// <para>
        /// The average (mean) value of the time series over a time interval window.
        /// </para>
        /// </summary>
        public double Average
        {
            get { return this._average.GetValueOrDefault(); }
            set { this._average = value; }
        }

        // Check to see if Average property is set
        internal bool IsSetAverage()
        {
            return this._average.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Count. 
        /// <para>
        /// The count of data points in the time series over a time interval window.
        /// </para>
        /// </summary>
        public double Count
        {
            get { return this._count.GetValueOrDefault(); }
            set { this._count = value; }
        }

        // Check to see if Count property is set
        internal bool IsSetCount()
        {
            return this._count.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Maximum. 
        /// <para>
        /// The maximum value of the time series over a time interval window.
        /// </para>
        /// </summary>
        public double Maximum
        {
            get { return this._maximum.GetValueOrDefault(); }
            set { this._maximum = value; }
        }

        // Check to see if Maximum property is set
        internal bool IsSetMaximum()
        {
            return this._maximum.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Minimum. 
        /// <para>
        /// The minimum value of the time series over a time interval window.
        /// </para>
        /// </summary>
        public double Minimum
        {
            get { return this._minimum.GetValueOrDefault(); }
            set { this._minimum = value; }
        }

        // Check to see if Minimum property is set
        internal bool IsSetMinimum()
        {
            return this._minimum.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property StandardDeviation. 
        /// <para>
        /// The standard deviation of the time series over a time interval window.
        /// </para>
        /// </summary>
        public double StandardDeviation
        {
            get { return this._standardDeviation.GetValueOrDefault(); }
            set { this._standardDeviation = value; }
        }

        // Check to see if StandardDeviation property is set
        internal bool IsSetStandardDeviation()
        {
            return this._standardDeviation.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Sum. 
        /// <para>
        /// The sum of the time series over a time interval window.
        /// </para>
        /// </summary>
        public double Sum
        {
            get { return this._sum.GetValueOrDefault(); }
            set { this._sum = value; }
        }

        // Check to see if Sum property is set
        internal bool IsSetSum()
        {
            return this._sum.HasValue; 
        }

    }
}