/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the license-manager-2018-08-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.LicenseManager.Model
{
    /// <summary>
    /// Describes a token.
    /// </summary>
    public partial class TokenData
    {
        private string _expirationTime;
        private string _licenseArn;
        private List<string> _roleArns = new List<string>();
        private string _status;
        private string _tokenId;
        private List<string> _tokenProperties = new List<string>();
        private string _tokenType;

        /// <summary>
        /// Gets and sets the property ExpirationTime. 
        /// <para>
        /// Token expiration time, in ISO8601-UTC format.
        /// </para>
        /// </summary>
        [AWSProperty(Max=50)]
        public string ExpirationTime
        {
            get { return this._expirationTime; }
            set { this._expirationTime = value; }
        }

        // Check to see if ExpirationTime property is set
        internal bool IsSetExpirationTime()
        {
            return this._expirationTime != null;
        }

        /// <summary>
        /// Gets and sets the property LicenseArn. 
        /// <para>
        /// Amazon Resource Name (ARN) of the license.
        /// </para>
        /// </summary>
        public string LicenseArn
        {
            get { return this._licenseArn; }
            set { this._licenseArn = value; }
        }

        // Check to see if LicenseArn property is set
        internal bool IsSetLicenseArn()
        {
            return this._licenseArn != null;
        }

        /// <summary>
        /// Gets and sets the property RoleArns. 
        /// <para>
        /// Amazon Resource Names (ARN) of the roles included in the token.
        /// </para>
        /// </summary>
        public List<string> RoleArns
        {
            get { return this._roleArns; }
            set { this._roleArns = value; }
        }

        // Check to see if RoleArns property is set
        internal bool IsSetRoleArns()
        {
            return this._roleArns != null && this._roleArns.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Status. 
        /// <para>
        /// Token status. The possible values are <code>AVAILABLE</code> and <code>DELETED</code>.
        /// </para>
        /// </summary>
        public string Status
        {
            get { return this._status; }
            set { this._status = value; }
        }

        // Check to see if Status property is set
        internal bool IsSetStatus()
        {
            return this._status != null;
        }

        /// <summary>
        /// Gets and sets the property TokenId. 
        /// <para>
        /// Token ID.
        /// </para>
        /// </summary>
        public string TokenId
        {
            get { return this._tokenId; }
            set { this._tokenId = value; }
        }

        // Check to see if TokenId property is set
        internal bool IsSetTokenId()
        {
            return this._tokenId != null;
        }

        /// <summary>
        /// Gets and sets the property TokenProperties. 
        /// <para>
        /// Data specified by the caller.
        /// </para>
        /// </summary>
        [AWSProperty(Max=3)]
        public List<string> TokenProperties
        {
            get { return this._tokenProperties; }
            set { this._tokenProperties = value; }
        }

        // Check to see if TokenProperties property is set
        internal bool IsSetTokenProperties()
        {
            return this._tokenProperties != null && this._tokenProperties.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property TokenType. 
        /// <para>
        /// Type of token generated. The supported value is <code>REFRESH_TOKEN</code>.
        /// </para>
        /// </summary>
        public string TokenType
        {
            get { return this._tokenType; }
            set { this._tokenType = value; }
        }

        // Check to see if TokenType property is set
        internal bool IsSetTokenType()
        {
            return this._tokenType != null;
        }

    }
}