/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the lightsail-2016-11-28.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Lightsail.Model
{
    /// <summary>
    /// Container for the parameters to the GetRelationalDatabaseEvents operation.
    /// Returns a list of events for a specific database in Amazon Lightsail.
    /// </summary>
    public partial class GetRelationalDatabaseEventsRequest : AmazonLightsailRequest
    {
        private int? _durationInMinutes;
        private string _pageToken;
        private string _relationalDatabaseName;

        /// <summary>
        /// Gets and sets the property DurationInMinutes. 
        /// <para>
        /// The number of minutes in the past from which to retrieve events. For example, to get
        /// all events from the past 2 hours, enter 120.
        /// </para>
        ///  
        /// <para>
        /// Default: <code>60</code> 
        /// </para>
        ///  
        /// <para>
        /// The minimum is 1 and the maximum is 14 days (20160 minutes).
        /// </para>
        /// </summary>
        public int DurationInMinutes
        {
            get { return this._durationInMinutes.GetValueOrDefault(); }
            set { this._durationInMinutes = value; }
        }

        // Check to see if DurationInMinutes property is set
        internal bool IsSetDurationInMinutes()
        {
            return this._durationInMinutes.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property PageToken. 
        /// <para>
        /// The token to advance to the next page of results from your request.
        /// </para>
        ///  
        /// <para>
        /// To get a page token, perform an initial <code>GetRelationalDatabaseEvents</code> request.
        /// If your results are paginated, the response will return a next page token that you
        /// can specify as the page token in a subsequent request.
        /// </para>
        /// </summary>
        public string PageToken
        {
            get { return this._pageToken; }
            set { this._pageToken = value; }
        }

        // Check to see if PageToken property is set
        internal bool IsSetPageToken()
        {
            return this._pageToken != null;
        }

        /// <summary>
        /// Gets and sets the property RelationalDatabaseName. 
        /// <para>
        /// The name of the database from which to get events.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string RelationalDatabaseName
        {
            get { return this._relationalDatabaseName; }
            set { this._relationalDatabaseName = value; }
        }

        // Check to see if RelationalDatabaseName property is set
        internal bool IsSetRelationalDatabaseName()
        {
            return this._relationalDatabaseName != null;
        }

    }
}