/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the mediaconnect-2018-11-14.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.MediaConnect.Model
{
    /// <summary>
    /// The settings for a flow entitlement.
    /// </summary>
    public partial class Entitlement
    {
        private int? _dataTransferSubscriberFeePercent;
        private string _description;
        private Encryption _encryption;
        private string _entitlementArn;
        private EntitlementStatus _entitlementStatus;
        private string _name;
        private List<string> _subscribers = new List<string>();

        /// <summary>
        /// Gets and sets the property DataTransferSubscriberFeePercent. Percentage from 0-100
        /// of the data transfer cost to be billed to the subscriber.
        /// </summary>
        public int DataTransferSubscriberFeePercent
        {
            get { return this._dataTransferSubscriberFeePercent.GetValueOrDefault(); }
            set { this._dataTransferSubscriberFeePercent = value; }
        }

        // Check to see if DataTransferSubscriberFeePercent property is set
        internal bool IsSetDataTransferSubscriberFeePercent()
        {
            return this._dataTransferSubscriberFeePercent.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Description. A description of the entitlement.
        /// </summary>
        public string Description
        {
            get { return this._description; }
            set { this._description = value; }
        }

        // Check to see if Description property is set
        internal bool IsSetDescription()
        {
            return this._description != null;
        }

        /// <summary>
        /// Gets and sets the property Encryption. The type of encryption that will be used on
        /// the output that is associated with this entitlement.
        /// </summary>
        public Encryption Encryption
        {
            get { return this._encryption; }
            set { this._encryption = value; }
        }

        // Check to see if Encryption property is set
        internal bool IsSetEncryption()
        {
            return this._encryption != null;
        }

        /// <summary>
        /// Gets and sets the property EntitlementArn. The ARN of the entitlement.
        /// </summary>
        [AWSProperty(Required=true)]
        public string EntitlementArn
        {
            get { return this._entitlementArn; }
            set { this._entitlementArn = value; }
        }

        // Check to see if EntitlementArn property is set
        internal bool IsSetEntitlementArn()
        {
            return this._entitlementArn != null;
        }

        /// <summary>
        /// Gets and sets the property EntitlementStatus. An indication of whether the entitlement
        /// is enabled.
        /// </summary>
        public EntitlementStatus EntitlementStatus
        {
            get { return this._entitlementStatus; }
            set { this._entitlementStatus = value; }
        }

        // Check to see if EntitlementStatus property is set
        internal bool IsSetEntitlementStatus()
        {
            return this._entitlementStatus != null;
        }

        /// <summary>
        /// Gets and sets the property Name. The name of the entitlement.
        /// </summary>
        [AWSProperty(Required=true)]
        public string Name
        {
            get { return this._name; }
            set { this._name = value; }
        }

        // Check to see if Name property is set
        internal bool IsSetName()
        {
            return this._name != null;
        }

        /// <summary>
        /// Gets and sets the property Subscribers. The AWS account IDs that you want to share
        /// your content with. The receiving accounts (subscribers) will be allowed to create
        /// their own flow using your content as the source.
        /// </summary>
        [AWSProperty(Required=true)]
        public List<string> Subscribers
        {
            get { return this._subscribers; }
            set { this._subscribers = value; }
        }

        // Check to see if Subscribers property is set
        internal bool IsSetSubscribers()
        {
            return this._subscribers != null && this._subscribers.Count > 0; 
        }

    }
}