/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the medialive-2017-10-14.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.MediaLive.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.MediaLive.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// TransferInputDevice Request Marshaller
    /// </summary>       
    public class TransferInputDeviceRequestMarshaller : IMarshaller<IRequest, TransferInputDeviceRequest> , IMarshaller<IRequest,AmazonWebServiceRequest>
    {
        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="input"></param>
        /// <returns></returns>
        public IRequest Marshall(AmazonWebServiceRequest input)
        {
            return this.Marshall((TransferInputDeviceRequest)input);
        }

        /// <summary>
        /// Marshaller the request object to the HTTP request.
        /// </summary>  
        /// <param name="publicRequest"></param>
        /// <returns></returns>
        public IRequest Marshall(TransferInputDeviceRequest publicRequest)
        {
            IRequest request = new DefaultRequest(publicRequest, "Amazon.MediaLive");
            request.Headers["Content-Type"] = "application/json";
            request.Headers[Amazon.Util.HeaderKeys.XAmzApiVersion] = "2017-10-14";            
            request.HttpMethod = "POST";

            if (!publicRequest.IsSetInputDeviceId())
                throw new AmazonMediaLiveException("Request object does not have required field InputDeviceId set");
            request.AddPathResource("{inputDeviceId}", StringUtils.FromString(publicRequest.InputDeviceId));
            request.ResourcePath = "/prod/inputDevices/{inputDeviceId}/transfer";
            using (StringWriter stringWriter = new StringWriter(CultureInfo.InvariantCulture))
            {
                JsonWriter writer = new JsonWriter(stringWriter);
                writer.WriteObjectStart();
                var context = new JsonMarshallerContext(request, writer);
                if(publicRequest.IsSetTargetCustomerId())
                {
                    context.Writer.WritePropertyName("targetCustomerId");
                    context.Writer.Write(publicRequest.TargetCustomerId);
                }

                if(publicRequest.IsSetTargetRegion())
                {
                    context.Writer.WritePropertyName("targetRegion");
                    context.Writer.Write(publicRequest.TargetRegion);
                }

                if(publicRequest.IsSetTransferMessage())
                {
                    context.Writer.WritePropertyName("transferMessage");
                    context.Writer.Write(publicRequest.TransferMessage);
                }

        
                writer.WriteObjectEnd();
                string snippet = stringWriter.ToString();
                request.Content = System.Text.Encoding.UTF8.GetBytes(snippet);
            }


            return request;
        }
        private static TransferInputDeviceRequestMarshaller _instance = new TransferInputDeviceRequestMarshaller();        

        internal static TransferInputDeviceRequestMarshaller GetInstance()
        {
            return _instance;
        }

        /// <summary>
        /// Gets the singleton.
        /// </summary>  
        public static TransferInputDeviceRequestMarshaller Instance
        {
            get
            {
                return _instance;
            }
        }

    }
}