/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the medialive-2017-10-14.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.MediaLive.Model
{
    /// <summary>
    /// The properties for a private VPC OutputWhen this property is specified, the output
    /// egress addresses will be created in a user specified VPC
    /// </summary>
    public partial class VpcOutputSettings
    {
        private List<string> _publicAddressAllocationIds = new List<string>();
        private List<string> _securityGroupIds = new List<string>();
        private List<string> _subnetIds = new List<string>();

        /// <summary>
        /// Gets and sets the property PublicAddressAllocationIds. List of public address allocation
        /// ids to associate with ENIs that will be created in Output VPC.Must specify one for
        /// SINGLE_PIPELINE, two for STANDARD channels
        /// </summary>
        public List<string> PublicAddressAllocationIds
        {
            get { return this._publicAddressAllocationIds; }
            set { this._publicAddressAllocationIds = value; }
        }

        // Check to see if PublicAddressAllocationIds property is set
        internal bool IsSetPublicAddressAllocationIds()
        {
            return this._publicAddressAllocationIds != null && this._publicAddressAllocationIds.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property SecurityGroupIds. A list of up to 5 EC2 VPC security group
        /// IDs to attach to the Output VPC network interfaces.If none are specified then the
        /// VPC default security group will be used
        /// </summary>
        public List<string> SecurityGroupIds
        {
            get { return this._securityGroupIds; }
            set { this._securityGroupIds = value; }
        }

        // Check to see if SecurityGroupIds property is set
        internal bool IsSetSecurityGroupIds()
        {
            return this._securityGroupIds != null && this._securityGroupIds.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property SubnetIds. A list of VPC subnet IDs from the same VPC.If
        /// STANDARD channel, subnet IDs must be mapped to two unique availability zones (AZ).
        /// </summary>
        [AWSProperty(Required=true)]
        public List<string> SubnetIds
        {
            get { return this._subnetIds; }
            set { this._subnetIds = value; }
        }

        // Check to see if SubnetIds property is set
        internal bool IsSetSubnetIds()
        {
            return this._subnetIds != null && this._subnetIds.Count > 0; 
        }

    }
}