/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the memorydb-2021-01-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.MemoryDB.Model
{
    /// <summary>
    /// Container for the parameters to the DescribeSnapshots operation.
    /// Returns information about cluster snapshots. By default, DescribeSnapshots lists all
    /// of your snapshots; it can optionally describe a single snapshot, or just the snapshots
    /// associated with a particular cluster.
    /// </summary>
    public partial class DescribeSnapshotsRequest : AmazonMemoryDBRequest
    {
        private string _clusterName;
        private int? _maxResults;
        private string _nextToken;
        private bool? _showDetail;
        private string _snapshotName;
        private string _source;

        /// <summary>
        /// Gets and sets the property ClusterName. 
        /// <para>
        /// A user-supplied cluster identifier. If this parameter is specified, only snapshots
        /// associated with that specific cluster are described.
        /// </para>
        /// </summary>
        public string ClusterName
        {
            get { return this._clusterName; }
            set { this._clusterName = value; }
        }

        // Check to see if ClusterName property is set
        internal bool IsSetClusterName()
        {
            return this._clusterName != null;
        }

        /// <summary>
        /// Gets and sets the property MaxResults. 
        /// <para>
        /// The maximum number of records to include in the response. If more records exist than
        /// the specified MaxResults value, a token is included in the response so that the remaining
        /// results can be retrieved.
        /// </para>
        /// </summary>
        public int MaxResults
        {
            get { return this._maxResults.GetValueOrDefault(); }
            set { this._maxResults = value; }
        }

        // Check to see if MaxResults property is set
        internal bool IsSetMaxResults()
        {
            return this._maxResults.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property NextToken. 
        /// <para>
        /// An optional argument to pass in case the total number of records exceeds the value
        /// of MaxResults. If nextToken is returned, there are more results available. The value
        /// of nextToken is a unique pagination token for each page. Make the call again using
        /// the returned token to retrieve the next page. Keep all other arguments unchanged.
        /// 
        /// </para>
        /// </summary>
        public string NextToken
        {
            get { return this._nextToken; }
            set { this._nextToken = value; }
        }

        // Check to see if NextToken property is set
        internal bool IsSetNextToken()
        {
            return this._nextToken != null;
        }

        /// <summary>
        /// Gets and sets the property ShowDetail. 
        /// <para>
        /// A Boolean value which if true, the shard configuration is included in the snapshot
        /// description.
        /// </para>
        /// </summary>
        public bool ShowDetail
        {
            get { return this._showDetail.GetValueOrDefault(); }
            set { this._showDetail = value; }
        }

        // Check to see if ShowDetail property is set
        internal bool IsSetShowDetail()
        {
            return this._showDetail.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property SnapshotName. 
        /// <para>
        /// A user-supplied name of the snapshot. If this parameter is specified, only this named
        /// snapshot is described.
        /// </para>
        /// </summary>
        public string SnapshotName
        {
            get { return this._snapshotName; }
            set { this._snapshotName = value; }
        }

        // Check to see if SnapshotName property is set
        internal bool IsSetSnapshotName()
        {
            return this._snapshotName != null;
        }

        /// <summary>
        /// Gets and sets the property Source. 
        /// <para>
        /// If set to system, the output shows snapshots that were automatically created by MemoryDB.
        /// If set to user the output shows snapshots that were manually created. If omitted,
        /// the output shows both automatically and manually created snapshots.
        /// </para>
        /// </summary>
        public string Source
        {
            get { return this._source; }
            set { this._source = value; }
        }

        // Check to see if Source property is set
        internal bool IsSetSource()
        {
            return this._source != null;
        }

    }
}