/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the personalize-2018-05-22.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Personalize.Model
{
    /// <summary>
    /// Provides the name and default range of a categorical hyperparameter and whether the
    /// hyperparameter is tunable. A tunable hyperparameter can have its value determined
    /// during hyperparameter optimization (HPO).
    /// </summary>
    public partial class DefaultCategoricalHyperParameterRange
    {
        private bool? _isTunable;
        private string _name;
        private List<string> _values = new List<string>();

        /// <summary>
        /// Gets and sets the property IsTunable. 
        /// <para>
        /// Whether the hyperparameter is tunable.
        /// </para>
        /// </summary>
        public bool IsTunable
        {
            get { return this._isTunable.GetValueOrDefault(); }
            set { this._isTunable = value; }
        }

        // Check to see if IsTunable property is set
        internal bool IsSetIsTunable()
        {
            return this._isTunable.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Name. 
        /// <para>
        /// The name of the hyperparameter.
        /// </para>
        /// </summary>
        [AWSProperty(Max=256)]
        public string Name
        {
            get { return this._name; }
            set { this._name = value; }
        }

        // Check to see if Name property is set
        internal bool IsSetName()
        {
            return this._name != null;
        }

        /// <summary>
        /// Gets and sets the property Values. 
        /// <para>
        /// A list of the categories for the hyperparameter.
        /// </para>
        /// </summary>
        [AWSProperty(Max=100)]
        public List<string> Values
        {
            get { return this._values; }
            set { this._values = value; }
        }

        // Check to see if Values property is set
        internal bool IsSetValues()
        {
            return this._values != null && this._values.Count > 0; 
        }

    }
}