/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the pinpoint-2016-12-01.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Pinpoint.Model
{
    /// <summary>
    /// Provides information about the results of a request to send a message to an endpoint
    /// address.
    /// </summary>
    public partial class MessageResponse
    {
        private string _applicationId;
        private Dictionary<string, EndpointMessageResult> _endpointResult = new Dictionary<string, EndpointMessageResult>();
        private string _requestId;
        private Dictionary<string, MessageResult> _result = new Dictionary<string, MessageResult>();

        /// <summary>
        /// Gets and sets the property ApplicationId. 
        /// <para>
        /// The unique identifier for the application that was used to send the message.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string ApplicationId
        {
            get { return this._applicationId; }
            set { this._applicationId = value; }
        }

        // Check to see if ApplicationId property is set
        internal bool IsSetApplicationId()
        {
            return this._applicationId != null;
        }

        /// <summary>
        /// Gets and sets the property EndpointResult. 
        /// <para>
        /// A map that contains a multipart response for each address that the message was sent
        /// to. In the map, the endpoint ID is the key and the result is the value.
        /// </para>
        /// </summary>
        public Dictionary<string, EndpointMessageResult> EndpointResult
        {
            get { return this._endpointResult; }
            set { this._endpointResult = value; }
        }

        // Check to see if EndpointResult property is set
        internal bool IsSetEndpointResult()
        {
            return this._endpointResult != null && this._endpointResult.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property RequestId. 
        /// <para>
        /// The identifier for the original request that the message was delivered for.
        /// </para>
        /// </summary>
        public string RequestId
        {
            get { return this._requestId; }
            set { this._requestId = value; }
        }

        // Check to see if RequestId property is set
        internal bool IsSetRequestId()
        {
            return this._requestId != null;
        }

        /// <summary>
        /// Gets and sets the property Result. 
        /// <para>
        /// A map that contains a multipart response for each address (email address, phone number,
        /// or push notification token) that the message was sent to. In the map, the address
        /// is the key and the result is the value.
        /// </para>
        /// </summary>
        public Dictionary<string, MessageResult> Result
        {
            get { return this._result; }
            set { this._result = value; }
        }

        // Check to see if Result property is set
        internal bool IsSetResult()
        {
            return this._result != null && this._result.Count > 0; 
        }

    }
}