/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the redshift-data-2019-12-20.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.RedshiftDataAPIService.Model
{
    /// <summary>
    /// Container for the parameters to the DescribeStatement operation.
    /// Describes the details about a specific instance when a query was run by the Amazon
    /// Redshift Data API. The information includes when the query started, when it finished,
    /// the query status, the number of rows returned, and the SQL statement.
    /// </summary>
    public partial class DescribeStatementRequest : AmazonRedshiftDataAPIServiceRequest
    {
        private string _id;

        /// <summary>
        /// Gets and sets the property Id. 
        /// <para>
        /// The identifier of the SQL statement to describe. This value is a universally unique
        /// identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates the number
        /// of the SQL statement. For example, <code>d9b6c0c9-0747-4bf4-b142-e8883122f766:2</code>
        /// has a suffix of <code>:2</code> that indicates the second SQL statement of a batch
        /// query. This identifier is returned by <code>BatchExecuteStatment</code>, <code>ExecuteStatement</code>,
        /// and <code>ListStatements</code>. 
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string Id
        {
            get { return this._id; }
            set { this._id = value; }
        }

        // Check to see if Id property is set
        internal bool IsSetId()
        {
            return this._id != null;
        }

    }
}