/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the resourcegroupstaggingapi-2017-01-26.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.ResourceGroupsTaggingAPI.Model
{
    /// <summary>
    /// Container for the parameters to the GetTagValues operation.
    /// Returns all tag values for the specified key that are used in the specified AWS Region
    /// for the calling AWS account.
    /// 
    ///  
    /// <para>
    /// This operation supports pagination, where the response can be sent in multiple pages.
    /// You should check the <code>PaginationToken</code> response parameter to determine
    /// if there are additional results available to return. Repeat the query, passing the
    /// <code>PaginationToken</code> response parameter value as an input to the next request
    /// until you recieve a <code>null</code> value. A null value for <code>PaginationToken</code>
    /// indicates that there are no more results waiting to be returned.
    /// </para>
    /// </summary>
    public partial class GetTagValuesRequest : AmazonResourceGroupsTaggingAPIRequest
    {
        private string _key;
        private string _paginationToken;

        /// <summary>
        /// Gets and sets the property Key. 
        /// <para>
        /// Specifies the tag key for which you want to list all existing values that are currently
        /// used in the specified AWS Region for the calling AWS account.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=128)]
        public string Key
        {
            get { return this._key; }
            set { this._key = value; }
        }

        // Check to see if Key property is set
        internal bool IsSetKey()
        {
            return this._key != null;
        }

        /// <summary>
        /// Gets and sets the property PaginationToken. 
        /// <para>
        /// Specifies a <code>PaginationToken</code> response value from a previous request to
        /// indicate that you want the next page of results. Leave this parameter empty in your
        /// initial request.
        /// </para>
        /// </summary>
        [AWSProperty(Min=0, Max=2048)]
        public string PaginationToken
        {
            get { return this._paginationToken; }
            set { this._paginationToken = value; }
        }

        // Check to see if PaginationToken property is set
        internal bool IsSetPaginationToken()
        {
            return this._paginationToken != null;
        }

    }
}