/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the servicecatalog-2015-12-10.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.ServiceCatalog.Model
{
    /// <summary>
    /// Container for the parameters to the ExecuteProvisionedProductServiceAction operation.
    /// Executes a self-service action against a provisioned product.
    /// </summary>
    public partial class ExecuteProvisionedProductServiceActionRequest : AmazonServiceCatalogRequest
    {
        private string _acceptLanguage;
        private string _executeToken;
        private Dictionary<string, List<string>> _parameters = new Dictionary<string, List<string>>();
        private string _provisionedProductId;
        private string _serviceActionId;

        /// <summary>
        /// Gets and sets the property AcceptLanguage. 
        /// <para>
        /// The language code.
        /// </para>
        ///  <ul> <li> 
        /// <para>
        ///  <code>en</code> - English (default)
        /// </para>
        ///  </li> <li> 
        /// <para>
        ///  <code>jp</code> - Japanese
        /// </para>
        ///  </li> <li> 
        /// <para>
        ///  <code>zh</code> - Chinese
        /// </para>
        ///  </li> </ul>
        /// </summary>
        [AWSProperty(Max=100)]
        public string AcceptLanguage
        {
            get { return this._acceptLanguage; }
            set { this._acceptLanguage = value; }
        }

        // Check to see if AcceptLanguage property is set
        internal bool IsSetAcceptLanguage()
        {
            return this._acceptLanguage != null;
        }

        /// <summary>
        /// Gets and sets the property ExecuteToken. 
        /// <para>
        /// An idempotency token that uniquely identifies the execute request.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=128)]
        public string ExecuteToken
        {
            get { return this._executeToken; }
            set { this._executeToken = value; }
        }

        // Check to see if ExecuteToken property is set
        internal bool IsSetExecuteToken()
        {
            return this._executeToken != null;
        }

        /// <summary>
        /// Gets and sets the property Parameters. 
        /// <para>
        /// A map of all self-service action parameters and their values. If a provided parameter
        /// is of a special type, such as <code>TARGET</code>, the provided value will override
        /// the default value generated by AWS Service Catalog. If the parameters field is not
        /// provided, no additional parameters are passed and default values will be used for
        /// any special parameters such as <code>TARGET</code>.
        /// </para>
        /// </summary>
        [AWSProperty(Min=1, Max=200)]
        public Dictionary<string, List<string>> Parameters
        {
            get { return this._parameters; }
            set { this._parameters = value; }
        }

        // Check to see if Parameters property is set
        internal bool IsSetParameters()
        {
            return this._parameters != null && this._parameters.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property ProvisionedProductId. 
        /// <para>
        /// The identifier of the provisioned product.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=100)]
        public string ProvisionedProductId
        {
            get { return this._provisionedProductId; }
            set { this._provisionedProductId = value; }
        }

        // Check to see if ProvisionedProductId property is set
        internal bool IsSetProvisionedProductId()
        {
            return this._provisionedProductId != null;
        }

        /// <summary>
        /// Gets and sets the property ServiceActionId. 
        /// <para>
        /// The self-service action identifier. For example, <code>act-fs7abcd89wxyz</code>.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=100)]
        public string ServiceActionId
        {
            get { return this._serviceActionId; }
            set { this._serviceActionId = value; }
        }

        // Check to see if ServiceActionId property is set
        internal bool IsSetServiceActionId()
        {
            return this._serviceActionId != null;
        }

    }
}