/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the signer-2017-08-25.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Signer.Model
{
    /// <summary>
    /// This is the response object from the ListProfilePermissions operation.
    /// </summary>
    public partial class ListProfilePermissionsResponse : AmazonWebServiceResponse
    {
        private string _nextToken;
        private List<Permission> _permissions = new List<Permission>();
        private int? _policySizeBytes;
        private string _revisionId;

        /// <summary>
        /// Gets and sets the property NextToken. 
        /// <para>
        /// String for specifying the next set of paginated results.
        /// </para>
        /// </summary>
        public string NextToken
        {
            get { return this._nextToken; }
            set { this._nextToken = value; }
        }

        // Check to see if NextToken property is set
        internal bool IsSetNextToken()
        {
            return this._nextToken != null;
        }

        /// <summary>
        /// Gets and sets the property Permissions. 
        /// <para>
        /// List of permissions associated with the Signing Profile.
        /// </para>
        /// </summary>
        public List<Permission> Permissions
        {
            get { return this._permissions; }
            set { this._permissions = value; }
        }

        // Check to see if Permissions property is set
        internal bool IsSetPermissions()
        {
            return this._permissions != null && this._permissions.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property PolicySizeBytes. 
        /// <para>
        /// Total size of the policy associated with the Signing Profile in bytes.
        /// </para>
        /// </summary>
        public int PolicySizeBytes
        {
            get { return this._policySizeBytes.GetValueOrDefault(); }
            set { this._policySizeBytes = value; }
        }

        // Check to see if PolicySizeBytes property is set
        internal bool IsSetPolicySizeBytes()
        {
            return this._policySizeBytes.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property RevisionId. 
        /// <para>
        /// The identifier for the current revision of profile permissions.
        /// </para>
        /// </summary>
        public string RevisionId
        {
            get { return this._revisionId; }
            set { this._revisionId = value; }
        }

        // Check to see if RevisionId property is set
        internal bool IsSetRevisionId()
        {
            return this._revisionId != null;
        }

    }
}