/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the signer-2017-08-25.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Signer.Model
{
    /// <summary>
    /// Container for the parameters to the RevokeSigningProfile operation.
    /// Changes the state of a signing profile to REVOKED. This indicates that signatures
    /// generated using the signing profile after an effective start date are no longer valid.
    /// </summary>
    public partial class RevokeSigningProfileRequest : AmazonSignerRequest
    {
        private DateTime? _effectiveTime;
        private string _profileName;
        private string _profileVersion;
        private string _reason;

        /// <summary>
        /// Gets and sets the property EffectiveTime. 
        /// <para>
        /// A timestamp for when revocation of a Signing Profile should become effective. Signatures
        /// generated using the signing profile after this timestamp are not trusted.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public DateTime EffectiveTime
        {
            get { return this._effectiveTime.GetValueOrDefault(); }
            set { this._effectiveTime = value; }
        }

        // Check to see if EffectiveTime property is set
        internal bool IsSetEffectiveTime()
        {
            return this._effectiveTime.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property ProfileName. 
        /// <para>
        /// The name of the signing profile to be revoked.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=2, Max=64)]
        public string ProfileName
        {
            get { return this._profileName; }
            set { this._profileName = value; }
        }

        // Check to see if ProfileName property is set
        internal bool IsSetProfileName()
        {
            return this._profileName != null;
        }

        /// <summary>
        /// Gets and sets the property ProfileVersion. 
        /// <para>
        /// The version of the signing profile to be revoked.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=10, Max=10)]
        public string ProfileVersion
        {
            get { return this._profileVersion; }
            set { this._profileVersion = value; }
        }

        // Check to see if ProfileVersion property is set
        internal bool IsSetProfileVersion()
        {
            return this._profileVersion != null;
        }

        /// <summary>
        /// Gets and sets the property Reason. 
        /// <para>
        /// The reason for revoking a signing profile.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=500)]
        public string Reason
        {
            get { return this._reason; }
            set { this._reason = value; }
        }

        // Check to see if Reason property is set
        internal bool IsSetReason()
        {
            return this._reason != null;
        }

    }
}