/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ssm-2014-11-06.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.SimpleSystemsManagement.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.SimpleSystemsManagement.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// ResourceDataSyncS3Destination Marshaller
    /// </summary>       
    public class ResourceDataSyncS3DestinationMarshaller : IRequestMarshaller<ResourceDataSyncS3Destination, JsonMarshallerContext> 
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="requestObject"></param>
        /// <param name="context"></param>
        /// <returns></returns>
        public void Marshall(ResourceDataSyncS3Destination requestObject, JsonMarshallerContext context)
        {
            if(requestObject.IsSetAWSKMSKeyARN())
            {
                context.Writer.WritePropertyName("AWSKMSKeyARN");
                context.Writer.Write(requestObject.AWSKMSKeyARN);
            }

            if(requestObject.IsSetBucketName())
            {
                context.Writer.WritePropertyName("BucketName");
                context.Writer.Write(requestObject.BucketName);
            }

            if(requestObject.IsSetDestinationDataSharing())
            {
                context.Writer.WritePropertyName("DestinationDataSharing");
                context.Writer.WriteObjectStart();

                var marshaller = ResourceDataSyncDestinationDataSharingMarshaller.Instance;
                marshaller.Marshall(requestObject.DestinationDataSharing, context);

                context.Writer.WriteObjectEnd();
            }

            if(requestObject.IsSetPrefix())
            {
                context.Writer.WritePropertyName("Prefix");
                context.Writer.Write(requestObject.Prefix);
            }

            if(requestObject.IsSetRegion())
            {
                context.Writer.WritePropertyName("Region");
                context.Writer.Write(requestObject.Region);
            }

            if(requestObject.IsSetSyncFormat())
            {
                context.Writer.WritePropertyName("SyncFormat");
                context.Writer.Write(requestObject.SyncFormat);
            }

        }

        /// <summary>
        /// Singleton Marshaller.
        /// </summary>  
        public readonly static ResourceDataSyncS3DestinationMarshaller Instance = new ResourceDataSyncS3DestinationMarshaller();

    }
}