/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the transcribe-2017-10-26.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.TranscribeService.Model
{
    /// <summary>
    /// Container for the parameters to the CreateLanguageModel operation.
    /// Creates a new custom language model. Use Amazon S3 prefixes to provide the location
    /// of your input files. The time it takes to create your model depends on the size of
    /// your training data.
    /// </summary>
    public partial class CreateLanguageModelRequest : AmazonTranscribeServiceRequest
    {
        private BaseModelName _baseModelName;
        private InputDataConfig _inputDataConfig;
        private CLMLanguageCode _languageCode;
        private string _modelName;

        /// <summary>
        /// Gets and sets the property BaseModelName. 
        /// <para>
        /// The Amazon Transcribe standard language model, or base model used to create your custom
        /// language model.
        /// </para>
        ///  
        /// <para>
        /// If you want to use your custom language model to transcribe audio with a sample rate
        /// of 16 kHz or greater, choose <code>Wideband</code>.
        /// </para>
        ///  
        /// <para>
        /// If you want to use your custom language model to transcribe audio with a sample rate
        /// that is less than 16 kHz, choose <code>Narrowband</code>.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public BaseModelName BaseModelName
        {
            get { return this._baseModelName; }
            set { this._baseModelName = value; }
        }

        // Check to see if BaseModelName property is set
        internal bool IsSetBaseModelName()
        {
            return this._baseModelName != null;
        }

        /// <summary>
        /// Gets and sets the property InputDataConfig. 
        /// <para>
        /// Contains the data access role and the Amazon S3 prefixes to read the required input
        /// files to create a custom language model.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public InputDataConfig InputDataConfig
        {
            get { return this._inputDataConfig; }
            set { this._inputDataConfig = value; }
        }

        // Check to see if InputDataConfig property is set
        internal bool IsSetInputDataConfig()
        {
            return this._inputDataConfig != null;
        }

        /// <summary>
        /// Gets and sets the property LanguageCode. 
        /// <para>
        /// The language of the input text you're using to train your custom language model.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public CLMLanguageCode LanguageCode
        {
            get { return this._languageCode; }
            set { this._languageCode = value; }
        }

        // Check to see if LanguageCode property is set
        internal bool IsSetLanguageCode()
        {
            return this._languageCode != null;
        }

        /// <summary>
        /// Gets and sets the property ModelName. 
        /// <para>
        /// The name you choose for your custom language model when you create it.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=200)]
        public string ModelName
        {
            get { return this._modelName; }
            set { this._modelName = value; }
        }

        // Check to see if ModelName property is set
        internal bool IsSetModelName()
        {
            return this._modelName != null;
        }

    }
}