/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the transfer-2018-11-05.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.Transfer.Model
{
    /// <summary>
    /// Container for the parameters to the UntagResource operation.
    /// Detaches a key-value pair from a resource, as identified by its Amazon Resource Name
    /// (ARN). Resources are users, servers, roles, and other entities.
    /// 
    ///  
    /// <para>
    /// No response is returned from this call.
    /// </para>
    /// </summary>
    public partial class UntagResourceRequest : AmazonTransferRequest
    {
        private string _arn;
        private List<string> _tagKeys = new List<string>();

        /// <summary>
        /// Gets and sets the property Arn. 
        /// <para>
        /// The value of the resource that will have the tag removed. An Amazon Resource Name
        /// (ARN) is an identifier for a specific Amazon Web Services resource, such as a server,
        /// user, or role.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=20, Max=1600)]
        public string Arn
        {
            get { return this._arn; }
            set { this._arn = value; }
        }

        // Check to see if Arn property is set
        internal bool IsSetArn()
        {
            return this._arn != null;
        }

        /// <summary>
        /// Gets and sets the property TagKeys. 
        /// <para>
        /// TagKeys are key-value pairs assigned to ARNs that can be used to group and search
        /// for resources by type. This metadata can be attached to resources for any purpose.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true, Min=1, Max=50)]
        public List<string> TagKeys
        {
            get { return this._tagKeys; }
            set { this._tagKeys = value; }
        }

        // Check to see if TagKeys property is set
        internal bool IsSetTagKeys()
        {
            return this._tagKeys != null && this._tagKeys.Count > 0; 
        }

    }
}