/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the xray-2016-04-12.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.XRay.Model
{
    /// <summary>
    /// A collection of fields identifying the service in a response time warning.
    /// </summary>
    public partial class ResponseTimeRootCauseService
    {
        private string _accountId;
        private List<ResponseTimeRootCauseEntity> _entityPath = new List<ResponseTimeRootCauseEntity>();
        private bool? _inferred;
        private string _name;
        private List<string> _names = new List<string>();
        private string _type;

        /// <summary>
        /// Gets and sets the property AccountId. 
        /// <para>
        /// The account ID associated to the service.
        /// </para>
        /// </summary>
        public string AccountId
        {
            get { return this._accountId; }
            set { this._accountId = value; }
        }

        // Check to see if AccountId property is set
        internal bool IsSetAccountId()
        {
            return this._accountId != null;
        }

        /// <summary>
        /// Gets and sets the property EntityPath. 
        /// <para>
        /// The path of root cause entities found on the service. 
        /// </para>
        /// </summary>
        public List<ResponseTimeRootCauseEntity> EntityPath
        {
            get { return this._entityPath; }
            set { this._entityPath = value; }
        }

        // Check to see if EntityPath property is set
        internal bool IsSetEntityPath()
        {
            return this._entityPath != null && this._entityPath.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Inferred. 
        /// <para>
        /// A Boolean value indicating if the service is inferred from the trace.
        /// </para>
        /// </summary>
        public bool Inferred
        {
            get { return this._inferred.GetValueOrDefault(); }
            set { this._inferred = value; }
        }

        // Check to see if Inferred property is set
        internal bool IsSetInferred()
        {
            return this._inferred.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property Name. 
        /// <para>
        /// The service name.
        /// </para>
        /// </summary>
        public string Name
        {
            get { return this._name; }
            set { this._name = value; }
        }

        // Check to see if Name property is set
        internal bool IsSetName()
        {
            return this._name != null;
        }

        /// <summary>
        /// Gets and sets the property Names. 
        /// <para>
        /// A collection of associated service names.
        /// </para>
        /// </summary>
        public List<string> Names
        {
            get { return this._names; }
            set { this._names = value; }
        }

        // Check to see if Names property is set
        internal bool IsSetNames()
        {
            return this._names != null && this._names.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Type. 
        /// <para>
        /// The type associated to the service.
        /// </para>
        /// </summary>
        public string Type
        {
            get { return this._type; }
            set { this._type = value; }
        }

        // Check to see if Type property is set
        internal bool IsSetType()
        {
            return this._type != null;
        }

    }
}