/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the marketplace-catalog-2018-09-17.normal.json service model.
 */

using Amazon.MarketplaceCatalog;
using Amazon.MarketplaceCatalog.Model;

using Moq;
using System;
using System.Linq;
using AWSSDK_DotNet35.UnitTests.TestTools;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace AWSSDK_DotNet35.UnitTests.PaginatorTests
{
    [TestClass]
    public class MarketplaceCatalogPaginatorTests
    {
        private static Mock<AmazonMarketplaceCatalogClient> _mockClient;

        [ClassInitialize()]
        public static void ClassInitialize(TestContext a)
        {
            _mockClient = new Mock<AmazonMarketplaceCatalogClient>("access key", "secret", Amazon.RegionEndpoint.USEast1);
        }

        [TestMethod]
        [TestCategory("UnitTest")]
        [TestCategory("MarketplaceCatalog")]
        public void ListChangeSetsTest_TwoPages()
        {
            var request = InstantiateClassGenerator.Execute<ListChangeSetsRequest>();

            var firstResponse = InstantiateClassGenerator.Execute<ListChangeSetsResponse>();
            var secondResponse = InstantiateClassGenerator.Execute<ListChangeSetsResponse>();
            secondResponse.NextToken = null;

            _mockClient.SetupSequence(x => x.ListChangeSets(request)).Returns(firstResponse).Returns(secondResponse);
            var paginator = _mockClient.Object.Paginators.ListChangeSets(request);
            
            Assert.AreEqual(2, paginator.Responses.ToList().Count);
        }

        [TestMethod]
        [TestCategory("UnitTest")]
        [TestCategory("MarketplaceCatalog")]
        [ExpectedException(typeof(System.InvalidOperationException), "Paginator has already been consumed and cannot be reused. Please create a new instance.")]
        public void ListChangeSetsTest__OnlyUsedOnce()
        {
            var request = InstantiateClassGenerator.Execute<ListChangeSetsRequest>();

            var response = InstantiateClassGenerator.Execute<ListChangeSetsResponse>();
            response.NextToken = null;

            _mockClient.Setup(x => x.ListChangeSets(request)).Returns(response);
            var paginator = _mockClient.Object.Paginators.ListChangeSets(request);

            // Should work the first time
            paginator.Responses.ToList();

            // Second time should throw an exception
            paginator.Responses.ToList();
        }


        [TestMethod]
        [TestCategory("UnitTest")]
        [TestCategory("MarketplaceCatalog")]
        public void ListEntitiesTest_TwoPages()
        {
            var request = InstantiateClassGenerator.Execute<ListEntitiesRequest>();

            var firstResponse = InstantiateClassGenerator.Execute<ListEntitiesResponse>();
            var secondResponse = InstantiateClassGenerator.Execute<ListEntitiesResponse>();
            secondResponse.NextToken = null;

            _mockClient.SetupSequence(x => x.ListEntities(request)).Returns(firstResponse).Returns(secondResponse);
            var paginator = _mockClient.Object.Paginators.ListEntities(request);
            
            Assert.AreEqual(2, paginator.Responses.ToList().Count);
        }

        [TestMethod]
        [TestCategory("UnitTest")]
        [TestCategory("MarketplaceCatalog")]
        [ExpectedException(typeof(System.InvalidOperationException), "Paginator has already been consumed and cannot be reused. Please create a new instance.")]
        public void ListEntitiesTest__OnlyUsedOnce()
        {
            var request = InstantiateClassGenerator.Execute<ListEntitiesRequest>();

            var response = InstantiateClassGenerator.Execute<ListEntitiesResponse>();
            response.NextToken = null;

            _mockClient.Setup(x => x.ListEntities(request)).Returns(response);
            var paginator = _mockClient.Object.Paginators.ListEntities(request);

            // Should work the first time
            paginator.Responses.ToList();

            // Second time should throw an exception
            paginator.Responses.ToList();
        }

    }
}