/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the securityhub-2018-10-26.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Text;
using System.Xml.Serialization;

using Amazon.SecurityHub.Model;
using Amazon.Runtime;
using Amazon.Runtime.Internal;
using Amazon.Runtime.Internal.Transform;
using Amazon.Runtime.Internal.Util;
using ThirdParty.Json.LitJson;

namespace Amazon.SecurityHub.Model.Internal.MarshallTransformations
{
    /// <summary>
    /// Vulnerability Marshaller
    /// </summary>       
    public class VulnerabilityMarshaller : IRequestMarshaller<Vulnerability, JsonMarshallerContext> 
    {
        /// <summary>
        /// Unmarshaller the response from the service to the response class.
        /// </summary>  
        /// <param name="requestObject"></param>
        /// <param name="context"></param>
        /// <returns></returns>
        public void Marshall(Vulnerability requestObject, JsonMarshallerContext context)
        {
            if(requestObject.IsSetCvss())
            {
                context.Writer.WritePropertyName("Cvss");
                context.Writer.WriteArrayStart();
                foreach(var requestObjectCvssListValue in requestObject.Cvss)
                {
                    context.Writer.WriteObjectStart();

                    var marshaller = CvssMarshaller.Instance;
                    marshaller.Marshall(requestObjectCvssListValue, context);

                    context.Writer.WriteObjectEnd();
                }
                context.Writer.WriteArrayEnd();
            }

            if(requestObject.IsSetId())
            {
                context.Writer.WritePropertyName("Id");
                context.Writer.Write(requestObject.Id);
            }

            if(requestObject.IsSetReferenceUrls())
            {
                context.Writer.WritePropertyName("ReferenceUrls");
                context.Writer.WriteArrayStart();
                foreach(var requestObjectReferenceUrlsListValue in requestObject.ReferenceUrls)
                {
                        context.Writer.Write(requestObjectReferenceUrlsListValue);
                }
                context.Writer.WriteArrayEnd();
            }

            if(requestObject.IsSetRelatedVulnerabilities())
            {
                context.Writer.WritePropertyName("RelatedVulnerabilities");
                context.Writer.WriteArrayStart();
                foreach(var requestObjectRelatedVulnerabilitiesListValue in requestObject.RelatedVulnerabilities)
                {
                        context.Writer.Write(requestObjectRelatedVulnerabilitiesListValue);
                }
                context.Writer.WriteArrayEnd();
            }

            if(requestObject.IsSetVendor())
            {
                context.Writer.WritePropertyName("Vendor");
                context.Writer.WriteObjectStart();

                var marshaller = VulnerabilityVendorMarshaller.Instance;
                marshaller.Marshall(requestObject.Vendor, context);

                context.Writer.WriteObjectEnd();
            }

            if(requestObject.IsSetVulnerablePackages())
            {
                context.Writer.WritePropertyName("VulnerablePackages");
                context.Writer.WriteArrayStart();
                foreach(var requestObjectVulnerablePackagesListValue in requestObject.VulnerablePackages)
                {
                    context.Writer.WriteObjectStart();

                    var marshaller = SoftwarePackageMarshaller.Instance;
                    marshaller.Marshall(requestObjectVulnerablePackagesListValue, context);

                    context.Writer.WriteObjectEnd();
                }
                context.Writer.WriteArrayEnd();
            }

        }

        /// <summary>
        /// Singleton Marshaller.
        /// </summary>  
        public readonly static VulnerabilityMarshaller Instance = new VulnerabilityMarshaller();

    }
}