/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the securityhub-2018-10-26.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.SecurityHub.Model
{
    /// <summary>
    /// A vulnerability associated with a finding.
    /// </summary>
    public partial class Vulnerability
    {
        private List<Cvss> _cvss = new List<Cvss>();
        private string _id;
        private List<string> _referenceUrls = new List<string>();
        private List<string> _relatedVulnerabilities = new List<string>();
        private VulnerabilityVendor _vendor;
        private List<SoftwarePackage> _vulnerablePackages = new List<SoftwarePackage>();

        /// <summary>
        /// Gets and sets the property Cvss. 
        /// <para>
        /// CVSS scores from the advisory related to the vulnerability.
        /// </para>
        /// </summary>
        public List<Cvss> Cvss
        {
            get { return this._cvss; }
            set { this._cvss = value; }
        }

        // Check to see if Cvss property is set
        internal bool IsSetCvss()
        {
            return this._cvss != null && this._cvss.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Id. 
        /// <para>
        /// The identifier of the vulnerability.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string Id
        {
            get { return this._id; }
            set { this._id = value; }
        }

        // Check to see if Id property is set
        internal bool IsSetId()
        {
            return this._id != null;
        }

        /// <summary>
        /// Gets and sets the property ReferenceUrls. 
        /// <para>
        /// A list of URLs that provide additional information about the vulnerability.
        /// </para>
        /// </summary>
        public List<string> ReferenceUrls
        {
            get { return this._referenceUrls; }
            set { this._referenceUrls = value; }
        }

        // Check to see if ReferenceUrls property is set
        internal bool IsSetReferenceUrls()
        {
            return this._referenceUrls != null && this._referenceUrls.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property RelatedVulnerabilities. 
        /// <para>
        /// List of vulnerabilities that are related to this vulnerability.
        /// </para>
        /// </summary>
        public List<string> RelatedVulnerabilities
        {
            get { return this._relatedVulnerabilities; }
            set { this._relatedVulnerabilities = value; }
        }

        // Check to see if RelatedVulnerabilities property is set
        internal bool IsSetRelatedVulnerabilities()
        {
            return this._relatedVulnerabilities != null && this._relatedVulnerabilities.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property Vendor. 
        /// <para>
        /// Information about the vendor that generates the vulnerability report.
        /// </para>
        /// </summary>
        public VulnerabilityVendor Vendor
        {
            get { return this._vendor; }
            set { this._vendor = value; }
        }

        // Check to see if Vendor property is set
        internal bool IsSetVendor()
        {
            return this._vendor != null;
        }

        /// <summary>
        /// Gets and sets the property VulnerablePackages. 
        /// <para>
        /// List of software packages that have the vulnerability.
        /// </para>
        /// </summary>
        public List<SoftwarePackage> VulnerablePackages
        {
            get { return this._vulnerablePackages; }
            set { this._vulnerablePackages = value; }
        }

        // Check to see if VulnerablePackages property is set
        internal bool IsSetVulnerablePackages()
        {
            return this._vulnerablePackages != null && this._vulnerablePackages.Count > 0; 
        }

    }
}