/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the securityhub-2018-10-26.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;
using System.Net;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.SecurityHub.Model
{
    /// <summary>
    /// A vendor that generates a vulnerability report.
    /// </summary>
    public partial class VulnerabilityVendor
    {
        private string _name;
        private string _url;
        private string _vendorCreatedAt;
        private string _vendorSeverity;
        private string _vendorUpdatedAt;

        /// <summary>
        /// Gets and sets the property Name. 
        /// <para>
        /// The name of the vendor.
        /// </para>
        /// </summary>
        [AWSProperty(Required=true)]
        public string Name
        {
            get { return this._name; }
            set { this._name = value; }
        }

        // Check to see if Name property is set
        internal bool IsSetName()
        {
            return this._name != null;
        }

        /// <summary>
        /// Gets and sets the property Url. 
        /// <para>
        /// The URL of the vulnerability advisory.
        /// </para>
        /// </summary>
        public string Url
        {
            get { return this._url; }
            set { this._url = value; }
        }

        // Check to see if Url property is set
        internal bool IsSetUrl()
        {
            return this._url != null;
        }

        /// <summary>
        /// Gets and sets the property VendorCreatedAt. 
        /// <para>
        /// Indicates when the vulnerability advisory was created.
        /// </para>
        ///  
        /// <para>
        /// Uses the <code>date-time</code> format specified in <a href="https://tools.ietf.org/html/rfc3339#section-5.6">RFC
        /// 3339 section 5.6, Internet Date/Time Format</a>. The value cannot contain spaces.
        /// For example, <code>2020-03-22T13:22:13.933Z</code>.
        /// </para>
        /// </summary>
        public string VendorCreatedAt
        {
            get { return this._vendorCreatedAt; }
            set { this._vendorCreatedAt = value; }
        }

        // Check to see if VendorCreatedAt property is set
        internal bool IsSetVendorCreatedAt()
        {
            return this._vendorCreatedAt != null;
        }

        /// <summary>
        /// Gets and sets the property VendorSeverity. 
        /// <para>
        /// The severity that the vendor assigned to the vulnerability.
        /// </para>
        /// </summary>
        public string VendorSeverity
        {
            get { return this._vendorSeverity; }
            set { this._vendorSeverity = value; }
        }

        // Check to see if VendorSeverity property is set
        internal bool IsSetVendorSeverity()
        {
            return this._vendorSeverity != null;
        }

        /// <summary>
        /// Gets and sets the property VendorUpdatedAt. 
        /// <para>
        /// Indicates when the vulnerability advisory was last updated.
        /// </para>
        ///  
        /// <para>
        /// Uses the <code>date-time</code> format specified in <a href="https://tools.ietf.org/html/rfc3339#section-5.6">RFC
        /// 3339 section 5.6, Internet Date/Time Format</a>. The value cannot contain spaces.
        /// For example, <code>2020-03-22T13:22:13.933Z</code>.
        /// </para>
        /// </summary>
        public string VendorUpdatedAt
        {
            get { return this._vendorUpdatedAt; }
            set { this._vendorUpdatedAt = value; }
        }

        // Check to see if VendorUpdatedAt property is set
        internal bool IsSetVendorUpdatedAt()
        {
            return this._vendorUpdatedAt != null;
        }

    }
}